@@ -18,7 +18,8 @@ proc_fix_unix()
         -name "*.in" -o \
         -name "config.guess" -o \
         -name "config.sub" -o \
-        -name "install-sh" \
+        -name "install-sh" -o \
+        -name "liquidward" \
 	")"`" 
    proc_dtou
    proc_chmod
@@ -63,7 +64,9 @@ proc_chmod()
 	-name "config.sub" -o \
 	-name "install-sh" -o \
 	-name "fix.sh" -o \
-	-name "u61" \
+	-name "liquidwar" -o \
+	-name "liquidwar-server" -o \
+	-name "liquidward" \
    ")" | xargs chmod 755
 }
 
