@@ -52,6 +52,8 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "advanced.h"
 #include "config.h"
 #include "dialog.h"
@@ -59,6 +61,8 @@
 #include "help.h"
 #include "time.h"
 #include "menu.h"
+#include "log.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -76,23 +80,25 @@ int advanced_options (void)
   int i,retour=0,choix=4;
   static int y_pos[5]={0,1,2,4,6};
 
+  memset(d,0,sizeof(d));
+
   for (i=0; i<5; ++i)
-      {
-       standard_button (d+i+4,0,y_pos[i],2,7);
-       d[i+4].proc=my_textbox_proc;
-      }
+    {
+      standard_button (d+i+4,0,y_pos[i],2,7);
+      d[i+4].proc=my_textbox_proc;
+    }
   for (i=0; i<5; ++i)
-      {
-       standard_button (d+i+9,1,y_pos[i],2,7);
-       d[i+9].proc=my_slider_proc;
-      }
+    {
+      standard_button (d+i+9,1,y_pos[i],2,7);
+      d[i+9].proc=my_slider_proc;
+    }
 
   quick_buttons(d);
-  d[4].dp="Attack";
-  d[5].dp="Defense";
-  d[6].dp="Base health";
-  d[7].dp="Winner help";
-  d[8].dp="Cpu strength";
+  d[4].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_ATTACK);
+  d[5].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_DEFENSE);
+  d[6].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_BASEHEALTH);
+  d[7].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_WINNERHELP);
+  d[8].dp=lw_lang_string(LW_LANG_STRING_ADVANCED_CPUSTRENGTH);
   d[9].d1=d[10].d1=d[11].d1=d[12].d1=16;
   d[13].d1=4;
   d[9].dp3=&CONFIG_FIGHTER_ATTACK;
@@ -101,40 +107,40 @@ int advanced_options (void)
   d[12].dp3=&CONFIG_NUMBER_INFLUENCE;
   d[13].dp3=&CONFIG_CPU_ADVANTAGE;
   for (i=9;i<14;++i)
-      {
-       d[i].dp=NULL;
-       d[i].dp2=slider_int;
-       temp=d[i].dp3;
-       d[i].d2=*temp;
-      }
+    {
+      d[i].dp=NULL;
+      d[i].dp2=slider_int;
+      temp=d[i].dp3;
+      d[i].d2=*temp;
+    }
   d[14].proc=0;
 
   while (retour==0)
-        {
-          choix=my_do_dialog (d,choix);
-          switch (choix)
-            {
-             case -1:
-             case MENU_QUICK_BACK:
-                  retour=1;
-                  break;
-             case MENU_QUICK_MAIN:
-                  retour=MENU_TOP;
-                  break;
-             case MENU_QUICK_QUIT:
-                  if (confirm_quit())
-                    retour=MENU_EXIT;
-                  break;
-             case MENU_QUICK_HELP:
-                  retour=display_help (HELP_TEXT_ADVANCED);
-                  break;
-             }
-        }
+    {
+      choix=my_do_dialog (d,choix);
+      switch (choix)
+	{
+	case -1:
+	case MENU_QUICK_BACK:
+	  retour=1;
+	  break;
+	case MENU_QUICK_MAIN:
+	  retour=MENU_TOP;
+	  break;
+	case MENU_QUICK_QUIT:
+	  if (confirm_quit())
+	    retour=MENU_EXIT;
+	  break;
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
+	  break;
+	}
+    }
 
   if (retour>0)
     retour--;
 
- return retour;
+  return retour;
 }
 
 
