@@ -62,35 +62,62 @@
 /*==================================================================*/
 
 typedef struct
-        {
-         int     val;           /* value which will be used when the*/
-                                /* will be put into the map. this   */
-                                /* value decreases at each round.   */
-         int     x;             /* x position of the cursor         */
-         int     y;             /* y position of the cursor         */
-         int     active;        /* true if the player who owns this */
-                                /* cursor is playing with it        */
-         int     team;          /* team the cursor belongs to       */
-         int     loose_time;    /* time at which this cursor has    */
-                                /* lost. it seems that the diff     */
-                                /* between cursor and team is not   */
-                                /* well defined 8-(                 */
-         int     score_order;   /* wether you are 1st or 2nd...     */
-         int     color_entry;   /* first color used by this cursor  */
-                                /* in the 256 color palette. again  */
-                                /* a cursor is associated to a team */
-         int     key_state;     /* this value holds the state of all*/
-                                /* the keys associated to the cursor*/
-                                /* it is a logical or between       */
-                                /* - CURSOR_KEY_UP                  */
-                                /* - CURSOR_KEY_RIGHT               */
-                                /* - CURSOR_KEY_DOWN                */
-                                /* - CURSOR_KEY_LEFT                */
-                                /* which are defined in move.h      */
-         int     cpu_or_human;  /* true if the player is a computer */
-         int     from_network;  /* true if the player is located on */
-                                /* a remote machine                 */
-        } CURSOR;
+{
+  /*
+   * value which will be used when the
+   * will be put into the map. this  
+   * value decreases at each round.  
+   */
+  int     val;
+  /* x position of the cursor         */
+  int     x;
+  /* y position of the cursor         */
+  int     y;           
+  /* 
+   * true if the player who owns this 
+   * cursor is playing with it        
+   */
+  int     active; 
+  /* team the cursor belongs to       */
+  int     team; 
+  /* 
+   * time at which this cursor has    
+   * lost. it seems that the diff     
+   * between cursor and team is not   
+   * well defined 8-(                 
+   */
+  int     loose_time; 
+  /* wether you are 1st or 2nd...     */
+  int     score_order;
+  /* 
+   * first color used by this cursor  
+   * in the 256 color palette. again  
+   * a cursor is associated to a team 
+   */
+  int     color_entry;
+  /* 
+   *      this value holds the state of all
+   * the keys associated to the cursor
+   * it is a logical or between   
+   * - CURSOR_KEY_UP    
+   * - CURSOR_KEY_RIGHT 
+   * - CURSOR_KEY_DOWN  
+   * - CURSOR_KEY_LEFT  
+   * which are defined in move.h      
+   */
+  int     key_state;  
+  /* true if the player is a computer */
+  int     cpu_or_human;
+  /* 
+   * true if the player is located on 
+   * a remote machine                 
+   */
+  int     from_network;
+  /*
+   * the name of the player
+   */
+  char name[NAME_SIZE+1];
+} CURSOR;
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -104,6 +131,6 @@ extern CURSOR CURRENT_CURSOR [NB_TEAMS];
 
 void reset_all_cursor (void);
 void apply_all_cursor (void);
-void auto_cursor (int index, int team);
+void auto_cursor (int index, int team, char *name);
 
 #endif
