@@ -78,11 +78,11 @@ int LOADED_SFX=0;
 int LOADED_WATER=0;
 int LOADED_MUSIC=0;
 
-SAMPLE *SAMPLE_SFX_TIME;
-SAMPLE *SAMPLE_SFX_WIN;
-SAMPLE *SAMPLE_SFX_GO;
-SAMPLE *SAMPLE_SFX_CLICK;
-SAMPLE *SAMPLE_SFX_LOOSE;
+SAMPLE *SAMPLE_SFX_TIME=NULL;
+SAMPLE *SAMPLE_SFX_WIN=NULL;
+SAMPLE *SAMPLE_SFX_GO=NULL;
+SAMPLE *SAMPLE_SFX_CLICK=NULL;
+SAMPLE *SAMPLE_SFX_LOOSE=NULL;
 
 SAMPLE *SAMPLE_WATER[SAMPLE_WATER_NUMBER];
 void   *RAW_MAP[RAW_MAP_MAX_NUMBER];
@@ -90,17 +90,16 @@ void   *RAW_MAP_ORDERED[RAW_MAP_MAX_NUMBER];
 void   *RAW_TEXTURE[RAW_TEXTURE_MAX_NUMBER];
 MIDI   *MIDI_MUSIC[MIDI_MUSIC_MAX_NUMBER];
 
-BITMAP *BACK_IMAGE;
+BITMAP *BACK_IMAGE=NULL;
 
-FONT *BIG_FONT;
-FONT *SMALL_FONT;
-BITMAP *BIG_MOUSE_CURSOR;
-BITMAP *SMALL_MOUSE_CURSOR;
+FONT *BIG_FONT=NULL;
+FONT *SMALL_FONT=NULL;
+BITMAP *BIG_MOUSE_CURSOR=NULL;
+BITMAP *SMALL_MOUSE_CURSOR=NULL;
+BITMAP *INVISIBLE_MOUSE_CURSOR=NULL;
 
-char *HELP_TEXT[LANGAGE_NUMBER][HELP_TEXT_NUMBER];
-
-static RGB *FONT_PALETTE;
-static RGB *BACK_PALETTE;
+static RGB *FONT_PALETTE=NULL;
+static RGB *BACK_PALETTE=NULL;
 
 /*------------------------------------------------------------------*/
 /* chargement des effets sonores                                    */
@@ -218,29 +217,12 @@ static void read_font_dat (DATAFILE *df)
   BIG_FONT=df[1].dat;
   SMALL_MOUSE_CURSOR=df[2].dat;
   BIG_MOUSE_CURSOR=df[3].dat;
+  INVISIBLE_MOUSE_CURSOR=df[5].dat;
 
   for (i=1; i<=17; ++i)
     GLOBAL_PALETTE[i]=FONT_PALETTE[i];
 }
 
-/*------------------------------------------------------------------*/
-static void read_help_dat (DATAFILE *df)
-{
-  int i,j,l;
-  DATAFILE *temp;
-
-  for (i=0;i<LANGAGE_NUMBER;++i)
-    {
-      temp=df[i].dat;
-      for (j=0;j<HELP_TEXT_NUMBER;++j)
-        {
-	  HELP_TEXT[i][j]=temp[j].dat;
-	  l=temp[j].size;
-	  HELP_TEXT[i][j][l-1]=0;
-        }
-    }
-}
-
 /*------------------------------------------------------------------*/
 static void read_music_dat (DATAFILE *df)
 {
@@ -273,15 +255,6 @@ int load_dat (void)
 
   display_success(loadable);
 
-  if (loadable)
-    {
-      log_print_str( "Loading help messages");
-      log_flush();
-      df=load_datafile_object (STARTUP_DAT_PATH,"help_dat");
-      if (result&=(df!=NULL))
-        read_help_dat (df[0].dat);
-      display_success (df!=NULL);
-    }
   if (loadable)
     {
       log_print_str( "Loading fonts");
@@ -389,9 +362,13 @@ static void load_custom_texture_callback(const char *file, int mode, int unused)
   if ((pointeur=archive_raw_texture(file)) !=NULL)
     {
       RAW_TEXTURE[RAW_TEXTURE_NUMBER++]=pointeur;
-      log_print_str(".");
-      log_flush();
+      log_print_str("+");
     }
+  else
+    {
+      log_print_str("-");
+    }
+  log_flush();
 }
 
 /*------------------------------------------------------------------*/
@@ -404,11 +381,11 @@ static int load_custom_texture (void)
   strcpy(buf,STARTUP_TEX_PATH);
   l=strlen(buf);
 
-#ifdef ALLEGRO_UNIX
-  strcpy(buf+l,"/*");
-#else
   strcpy(buf+l,"\\*.*");
-#endif
+
+  fix_filename_case(buf);
+  fix_filename_slashes(buf);
+
   for_each_file(buf,FA_RDONLY,load_custom_texture_callback,0);
 
   return result;
@@ -422,8 +399,11 @@ static void load_custom_map_callback(const char *file, int mode, int unused)
   if ((pointeur=archive_raw_map(file)) !=NULL)
     {
       RAW_MAP[RAW_MAP_NUMBER++]=pointeur;
-      log_print_str(".");
-      log_flush();
+      log_print_str("+");
+    }
+  else
+    {
+      log_print_str("-");
     }
 }
 
@@ -437,13 +417,13 @@ static int load_custom_map (void)
   strcpy(buf,STARTUP_MAP_PATH);
   l=strlen(buf);
 
-#ifdef ALLEGRO_UNIX
-  strcpy(buf+l,"/*");
-#else
   strcpy(buf+l,"\\*.*");
-#endif
-  for_each_file(buf,FA_RDONLY,load_custom_map_callback,0);
 
+  fix_filename_case(buf);
+  fix_filename_slashes(buf);
+
+  for_each_file(buf,FA_RDONLY,load_custom_map_callback,0);
+  
   return result;
 }
 
@@ -455,9 +435,13 @@ static void load_custom_music_callback(const char *file, int mode, int unused)
   if ((pointeur=load_midi(file)) !=NULL)
     {
       MIDI_MUSIC[MIDI_MUSIC_NUMBER++]=pointeur;
-      log_print_str(".");
-      log_flush();
+      log_print_str("+");
     }
+  else
+    {
+      log_print_str("-");
+    }
+  log_flush();
 }
 
 /*------------------------------------------------------------------*/
@@ -470,11 +454,11 @@ static int load_custom_music (void)
   strcpy(buf,STARTUP_MID_PATH);
   l=strlen(buf);
 
-#ifdef ALLEGRO_UNIX
-  strcpy(buf+l,"/*");
-#else
   strcpy(buf+l,"\\*.*");
-#endif
+
+  fix_filename_case(buf);
+  fix_filename_slashes(buf);
+
   for_each_file(buf,FA_RDONLY,load_custom_music_callback,0);
 
   return result;
@@ -489,7 +473,7 @@ int load_custom (void)
     {
       log_print_str( "Loading custom textures from \"");
       log_print_str(STARTUP_TEX_PATH);
-      log_print_str("\"");
+      log_print_str("\" ");
       log_flush();
       success=load_custom_texture ();
       if (!success)
@@ -501,7 +485,7 @@ int load_custom (void)
     {
       log_print_str( "Loading custom maps from \"");
       log_print_str(STARTUP_MAP_PATH);
-      log_print_str("\"");
+      log_print_str("\" ");
       log_flush();
       success=load_custom_map();
       if (!success)
@@ -513,7 +497,7 @@ int load_custom (void)
     {
       log_print_str( "Loading custom musics from \"");
       log_print_str(STARTUP_MID_PATH);
-      log_print_str("\"");
+      log_print_str("\" ");
       log_flush();
       success=load_custom_music();
       if (!success)
@@ -573,8 +557,8 @@ void order_map (void)
 
       for (i=0;i<RAW_MAP_NUMBER-1;++i)
 	{
-	  strcpy(name1,get_map_readable_name(i));
-	  strcpy(name2,get_map_readable_name(i+1));
+	  strcpy(name1,get_map_readable_name(i,0));
+	  strcpy(name2,get_map_readable_name(i+1,0));
 	  if (strcmp(name1,name2)>0)
 	    {
 	      incorrect_order=1;
