@@ -82,9 +82,15 @@
 /*------------------------------------------------------------------*/
 static void exit_all (void)
 {
-#ifdef ALLEGRO_DOS
+  /*
+   * we take a rest before and after calling set_gfx_mode(GFX_TEXT,...)
+   * This is an attempt to get rid of a hideous bug under X-Win,
+   * which said that there was a "bad file descriptor"
+   */
+  rest(100);
   set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
-#endif
+  rest(100);
+
   log_println();
   log_println_str ("Leaving Allegro (http://www.talula.demon.co.uk/allegro)");
   save_config_options ();
