@@ -83,6 +83,7 @@
 #include "viewport.h"
 #include "watchdog.h"
 #include "network.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* definitions de constantes                                        */
@@ -96,6 +97,8 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+int LW_GAME_RUNNING=0;
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -116,13 +119,11 @@ void calc_playing_teams(void)
    */
   for (i=0;i<NB_TEAMS;++i)
     {
-      /*
-       * check if a color has been selected, a value of 0 indicates
-       * that no color has been selected, therefore the team is
-       * disactivated
-       */
       if (LW_NETWORK_ON)
 	{
+	  /*
+	   * We're in a network game
+	   */
 	  if (LW_NETWORK_INFO[i].active)
 	    {
 	      PLAYING_TEAMS++;
@@ -130,11 +131,13 @@ void calc_playing_teams(void)
 	}
       else
 	{ 
-	  if (CONFIG_TEAM_COLOR[i])
-	    /*
-	     * OK, there's a chosen color, increment the result
-	     */
-	    PLAYING_TEAMS++;
+	  /*
+	   * Not a network game, we only check the local config
+	   */
+	  if (CONFIG_CONTROL_TYPE[i] != CONFIG_CONTROL_TYPE_OFF)
+	    {
+	      PLAYING_TEAMS++;
+	    }
 	}
     }
 }
@@ -170,7 +173,8 @@ static void init_cursor_control_method (void)
        * we check the config to see wether the cursor is moved
        * by a computer or a human.
        */
-      CURRENT_CURSOR[i].cpu_or_human=CONFIG_CPU_CONTROL[i];
+      CURRENT_CURSOR[i].cpu_or_human=
+	(CONFIG_CONTROL_TYPE[i]==CONFIG_CONTROL_TYPE_CPU);
     }
 }
 
@@ -255,9 +259,10 @@ char  *init_game (void)
   if (!message &&
       (CURRENT_AREA_BACK=create_textured_map (CONFIG_LEVEL_MAP,
                                               CONFIG_LEVEL_FG,
-                                              CONFIG_LEVEL_BG))
+                                              CONFIG_LEVEL_BG,
+					      LW_NETWORK_ON))
       ==NULL)
-    message="AB mem fail";
+    message=lw_lang_string(LW_LANG_STRING_GAME_BACKMEMFAIL);
 
   /*
    * creation of the map which will be used for display
@@ -267,27 +272,28 @@ char  *init_game (void)
   if (!message &&
       (CURRENT_AREA_DISP=create_textured_map (CONFIG_LEVEL_MAP,
                                               CONFIG_LEVEL_FG,
-                                              CONFIG_LEVEL_BG))
+                                              CONFIG_LEVEL_BG,
+					      LW_NETWORK_ON))
       ==NULL)
-    message="AD mem fail";
+    message=lw_lang_string(LW_LANG_STRING_GAME_DISPMEMFAIL);
 
   /*
    * creation of the mesh, see mesh.c for details
    */
   if (!message && create_mesh())
-    message="Mesh nem fail";
+    message=lw_lang_string(LW_LANG_STRING_GAME_MESHMEMFAIL);
 
   /*
    * creation of the game area, see area.c for details
    */
   if (!message && create_game_area())
-    message="Area nem fail";
+    message=lw_lang_string(LW_LANG_STRING_GAME_AREAMEMFAIL);
 
   /*
    * creation of the armies, see army.c for details
    */
   if (!message && create_army())
-    message="Army nem fail";
+    message=lw_lang_string(LW_LANG_STRING_GAME_ARMYMEMFAIL);
 
   /*
    * what to do nothing failed (play!)
@@ -609,7 +615,7 @@ int game (void)
   /*
    * resets input buffers and control interfaces
    */
-  reset_mouse_control();
+  lw_mouse_reset_control();
   reset_computer_path ();
   /*
    * resets profile information, so that they are not affected
