@@ -60,6 +60,7 @@
 #include "gfxmode.h"
 #include "startup.h"
 #include "init.h"
+#include "mouse.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -187,14 +188,14 @@ int set_resolution (int res, int flip, int fullscreen)
       if (SCREEN_W>=640)
         {
 	  font=BIG_FONT;
-	  set_mouse_sprite (BIG_MOUSE_CURSOR);
         }
       else
 	{
           font=SMALL_FONT;
-          set_mouse_sprite (SMALL_MOUSE_CURSOR);
 	}
       
+      lw_mouse_show();
+      
       set_window_title("Liquid War " LW_VERSION);
     }
 
