@@ -53,6 +53,7 @@
 /*==================================================================*/
 
 #include <stdio.h>
+#include <string.h>
 
 #include "back.h"
 #include "config.h"
@@ -64,6 +65,7 @@
 #include "menu.h"
 #include "sound.h"
 #include "wave.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -78,7 +80,8 @@ static char *get_game_res_str(void)
 {
   static char str[30];
 
-  sprintf(str,"Game:%dx%d",
+  sprintf(str,"%s:%dx%d",
+	  lw_lang_string(LW_LANG_STRING_GRAPHICS_GAME),
 	  GFX_MODE_W[CONFIG_GFX_GAME],
 	  GFX_MODE_H[CONFIG_GFX_GAME]);
 
@@ -90,7 +93,8 @@ static char *get_menu_res_str(void)
 {
   static char str[30];
 
-  sprintf(str,"Menu:%dx%d",
+  sprintf(str,"%s:%dx%d",
+	  lw_lang_string(LW_LANG_STRING_GRAPHICS_MENU),
 	  GFX_MODE_W[CONFIG_GFX_MENU],
 	  GFX_MODE_H[CONFIG_GFX_MENU]);
 
@@ -101,27 +105,27 @@ static char *get_menu_res_str(void)
 static char *get_wave_mode_str(void)
 {
   if (CONFIG_WAVE_ON)
-    return ("On");
+    return (lw_lang_string(LW_LANG_STRING_GRAPHICS_ON));
   else
-    return ("Off");
+    return (lw_lang_string(LW_LANG_STRING_GRAPHICS_OFF));
 }
 
 /*------------------------------------------------------------------*/
 static char *get_page_flip_str(void)
 {
   if (CONFIG_PAGE_FLIP)
-    return ("On");
+    return (lw_lang_string(LW_LANG_STRING_GRAPHICS_ON));
   else
-    return ("Off");
+    return (lw_lang_string(LW_LANG_STRING_GRAPHICS_OFF));
 }
 
 /*------------------------------------------------------------------*/
 static char *get_fullscreen_str(void)
 {
   if (CONFIG_FULLSCREEN)
-    return ("Fullscreen");
+    return (lw_lang_string(LW_LANG_STRING_GRAPHICS_FULLSCREEN));
   else
-    return ("Windowed");
+    return (lw_lang_string(LW_LANG_STRING_GRAPHICS_WINDOWED));
 }
 
 /*------------------------------------------------------------------*/
@@ -148,7 +152,7 @@ static int slider_menu_res (void *dp3, int d2)
   *changed=1;
 
   my_set_palette ();
-  /*     my_fade_in ();*/
+
   return 0;
 }
 
@@ -177,6 +181,8 @@ int graphic_options (void)
   static int y_pos[7]={0,1,3,4,5,6,8};
   int *temp;
 
+  memset(d,0,sizeof(d));
+
   display_back_image();
   while (retour==0)
     {
@@ -192,16 +198,16 @@ int graphic_options (void)
 	}
 
       standard_button (d+18,0,9,1,10);
-      d[18].dp="Advanced";
+      d[18].dp=lw_lang_string(LW_LANG_STRING_GRAPHICS_ADVANCED);
 
       quick_buttons(d);
-      d[4].dp="Video mode";
-      d[5].dp="Brightness";
+      d[4].dp=lw_lang_string(LW_LANG_STRING_GRAPHICS_VIDEOMODE);
+      d[5].dp=lw_lang_string(LW_LANG_STRING_GRAPHICS_BRIGHTNESS);
       d[6].dp=get_menu_res_str();
       d[7].dp=get_game_res_str();
-      d[8].dp="Viewport size";
-      d[9].dp="Page flipping";
-      d[10].dp="Waves (F4)";
+      d[8].dp=lw_lang_string(LW_LANG_STRING_GRAPHICS_VIEWPORTSIZE);
+      d[9].dp=lw_lang_string(LW_LANG_STRING_GRAPHICS_PAGEFLIPPING);
+      d[10].dp=lw_lang_string(LW_LANG_STRING_GRAPHICS_WAVES);
       d[11].dp=d[12].dp=d[13].dp=d[14].dp=d[15].dp=d[16].dp=d[17].dp=NULL;
       d[12].d1=18;
       d[13].d1=d[14].d1=4;
@@ -306,14 +312,15 @@ int graphic_options (void)
 		  else
 		    display_back_image();
 		  break;
-		case MENU_QUICK_HELP:
-		  retour=display_help (HELP_TEXT_GRAPHICS);
-		  display_back_image ();
+		case MENU_QUICK_PLAY:
+		  retour=MENU_PLAY;
 		  break;
 		case 11:
 		  CONFIG_FULLSCREEN=CONFIG_FULLSCREEN ? 0 : 1;
 		  d[11].dp=get_fullscreen_str();
+		  scare_mouse();
 		  my_button_proc (MSG_DRAW,d+11,0);
+		  unscare_mouse();
 		  fullscreen_changed=1;
 		  my_fade_out();
 		  set_resolution(d[13].d2,0,CONFIG_FULLSCREEN);
@@ -321,12 +328,16 @@ int graphic_options (void)
 		case 16:
 		  CONFIG_PAGE_FLIP=CONFIG_PAGE_FLIP ? 0 : 1;
 		  d[16].dp=get_page_flip_str();
+		  scare_mouse();
 		  my_button_proc (MSG_DRAW,d+16,0);
+		  unscare_mouse();
 		  break;
 		case 17:
 		  CONFIG_WAVE_ON=CONFIG_WAVE_ON ? 0 : 1;
 		  d[17].dp=get_wave_mode_str();
+		  scare_mouse();
 		  my_button_proc (MSG_DRAW,d+17,0);
+		  unscare_mouse();
 		  break;
 		case 18:
 		  retour=wave_options();
