@@ -182,11 +182,11 @@ void wait_no_key (void)
 
   start_tick=get_ticker();
 
-  reset_mouse_control ();
+  lw_mouse_reset_control ();
   do
     {
       touched=0;
-      update_mouse_control ();
+      lw_mouse_update_control ();
       my_poll_joystick ();
       for (i=0;i<256;++i)
 	if (is_touched_key(i))
@@ -204,11 +204,11 @@ int wait_key_pressed (void)
 
   start_tick=get_ticker();
 
-  reset_mouse_control ();
+  lw_mouse_reset_control ();
   while ((!touched) && 
 	 get_ticker()<start_tick+LW_KEYBOARD_WAITKEYPRESSED_TICK_LIMIT)
     {
-      update_mouse_control ();
+      lw_mouse_update_control ();
       my_poll_joystick ();
       for (i=0;i<256 && !touched;++i)
 	if (is_touched_key(i))
