@@ -372,7 +372,7 @@ void *archive_raw_map (const char *filename)
 	  memset(readable_name_buffer,0,sizeof(readable_name_buffer));
 	  sprintf(readable_name_buffer,"Custom map %d",index++);
 	  memcpy(result+8,readable_name_buffer,
-		 LW_MAP_READABLE_NAME_SIZE);;
+		 LW_MAP_READABLE_NAME_SIZE);
 
 	  /*
 	   * And at last we write the map itself
@@ -387,7 +387,7 @@ void *archive_raw_map (const char *filename)
 }
 
 /*------------------------------------------------------------------*/
-static void *get_map_safe(int num)
+static void *get_map_safe(int num, int network)
 {
   void *raw_map=NULL;
 
@@ -397,7 +397,7 @@ static void *get_map_safe(int num)
   if (num<0)
     num=0;
 
-  if (LW_NETWORK_ON && LW_NETWORK_RAW_MAP != NULL)
+  if (network)
     raw_map=LW_NETWORK_RAW_MAP;
   else
     raw_map=RAW_MAP_ORDERED[num];
@@ -406,7 +406,8 @@ static void *get_map_safe(int num)
 }
 
 /*------------------------------------------------------------------*/
-BITMAP *create_bicolor_map (int num, int fg, int bg)
+BITMAP *create_bicolor_map (int num, int fg, int bg,
+			    int network)
 {
   int   pos_dst,pos_src,w,h,i,l,color;
   signed char *data_dst,*data_src;
@@ -414,7 +415,7 @@ BITMAP *create_bicolor_map (int num, int fg, int bg)
   BITMAP *result;
   void *raw_map;
 
-  raw_map=get_map_safe(num);
+  raw_map=get_map_safe(num,network);
 
   data_src=raw_map;
   data2=raw_map;
@@ -447,7 +448,8 @@ BITMAP *create_bicolor_map (int num, int fg, int bg)
 }
 
 /*------------------------------------------------------------------*/
-BITMAP *create_textured_map (int num, int fg, int bg)
+BITMAP *create_textured_map (int num, int fg, int bg,
+			     int network)
 {
   int   x,y,w,h,color;
   BITMAP *result=NULL,*bg_tex,*fg_tex;
@@ -464,7 +466,7 @@ BITMAP *create_textured_map (int num, int fg, int bg)
       fg_w=fg_tex->w;
       fg_h=fg_tex->h;
 
-      result=create_bicolor_map (num,1,0);
+      result=create_bicolor_map (num,1,0,network);
       if (result)
 	{
 	  w=result->w;
@@ -491,13 +493,13 @@ BITMAP *create_textured_map (int num, int fg, int bg)
 }
 
 /*------------------------------------------------------------------*/
-char *get_map_readable_name (int num)
+char *get_map_readable_name (int num, int network)
 {
   static char result[LW_MAP_READABLE_NAME_SIZE+1];
   void *raw_map;
   char *char_ptr;
 
-  raw_map=get_map_safe(num);
+  raw_map=get_map_safe(num,network);
   char_ptr=(char *) raw_map;
 
   memcpy(result,char_ptr+8,LW_MAP_READABLE_NAME_SIZE);
@@ -506,13 +508,13 @@ char *get_map_readable_name (int num)
 }
 
 /*------------------------------------------------------------------*/
-void get_map_res (int num,int *w,int *h)
+void get_map_res (int num,int *w,int *h,int network)
 {
   void *raw_map;
   short *res_ptr;
   short res_w,res_h;
 
-  raw_map=get_map_safe(num);
+  raw_map=get_map_safe(num,network);
   res_ptr=(short *) raw_map;
 
   res_w=res_ptr[2];
