@@ -68,9 +68,9 @@
 /*==================================================================*/
 
 void *archive_raw_map (const char *filename);
-BITMAP *create_bicolor_map (int, int, int);
-BITMAP *create_textured_map (int, int, int);
-char *get_map_readable_name (int num);
-void get_map_res (int num,int *w,int *h);
+BITMAP *create_bicolor_map (int num, int fg, int bg, int network);
+BITMAP *create_textured_map (int num, int fg, int bg, int network);
+char *get_map_readable_name (int num, int network);
+void get_map_res (int num,int *w,int *h, int network);
 
 #endif
