@@ -52,6 +52,8 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "back.h"
 #include "dialog.h"
 #include "disk.h"
@@ -60,10 +62,13 @@
 #include "menu.h"
 #include "options.h"
 #include "play.h"
+#include "netplay.h"
 #include "team.h"
 #include "netgame.h"
 #include "network.h"
 #include "error.h"
+#include "about.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* fonctions                                                        */
@@ -74,20 +79,22 @@ int confirm_quit (void)
 {
   DIALOG d[3];
 
+  memset(d,0,sizeof(d));
+
   d[2].proc=NULL;
   standard_button (d,0,0,2,1);
   standard_button (d+1,1,0,2,1);
-  d[0].dp="Exit";
+  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXIT);
 #ifdef ALLEGRO_DOS
-  d[0].dp="Exit to DOS";
+  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXITDOS);
 #endif
 #ifdef ALLEGRO_WINDOWS
-  d[0].dp="Exit to Windows";
+  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXITWINDOWS);
 #endif
 #ifdef ALLEGRO_UNIX
-  d[0].dp="Exit to Unix";
+  d[0].dp=lw_lang_string(LW_LANG_STRING_MENU_EXITUNIX);
 #endif
-  d[1].dp="Back to LW";
+  d[1].dp=lw_lang_string(LW_LANG_STRING_MENU_BACK);
   d[0].key='d';
   d[1].key='w';
 
@@ -104,6 +111,8 @@ void main_menu (void)
   DIALOG d[11];
   int i,choix=4,retour=0;
 
+  memset(d,0,sizeof(d));
+
   display_back_image ();
   /*
     dp=init_dialog (d,4);
@@ -120,12 +129,12 @@ void main_menu (void)
       quick_buttons(d);
       d[MENU_QUICK_BACK].flags=D_HIDDEN;
       d[MENU_QUICK_MAIN].flags=D_HIDDEN;
-      d[4].dp="Play";
-      d[5].dp="Net game";
-      d[6].dp="Map";
-      d[7].dp="Teams";
-      d[8].dp="Options";
-      d[9].dp="About";
+      d[4].dp=lw_lang_string(LW_LANG_STRING_MENU_PLAY);
+      d[5].dp=lw_lang_string(LW_LANG_STRING_MENU_NETGAME);
+      d[6].dp=lw_lang_string(LW_LANG_STRING_MENU_MAP);
+      d[7].dp=lw_lang_string(LW_LANG_STRING_MENU_TEAMS);
+      d[8].dp=lw_lang_string(LW_LANG_STRING_MENU_OPTIONS);
+      d[9].dp=lw_lang_string(LW_LANG_STRING_MENU_ABOUT);
       d[10].proc=0;
 
       choix=my_do_dialog (d,choix);
@@ -136,8 +145,8 @@ void main_menu (void)
 	  if (confirm_quit())
 	    retour=MENU_EXIT;
 	  break;
-	case MENU_QUICK_HELP:
-	  retour=display_help (HELP_TEXT_MAIN);
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
 	  break;
 	case 4:
 	  LW_NETWORK_ON=0;
@@ -160,9 +169,27 @@ void main_menu (void)
 	  retour=options ();
 	  break;
 	case 9:
-	  retour=display_help (HELP_TEXT_ABOUT);
+	  retour=lw_about ();
 	  break;
 	}
+      /*
+       * We handle the quick top-right "Play" button
+       */
+      if (retour==MENU_PLAY)
+	{
+	  if (LW_NETWORK_ON)
+	    {
+#ifndef ALLEGRO_DOS
+	      retour=netplay_sequence ();
+#else
+	      retour=play_sequence ();
+#endif
+	    }
+	  else
+	    {
+	      retour=play_sequence ();
+	    }
+	}
     }
 }
 
