@@ -56,6 +56,7 @@
 #include "config.h"
 #include "map.h"
 #include "mesh.h"
+#include "network.h"
 
 /*==================================================================*/
 /* types                                                            */
@@ -335,7 +336,7 @@ int create_mesh(void)
   CURRENT_AREA_H=0;
 
   if ((map=create_bicolor_map
-       (CONFIG_LEVEL_MAP, MESH_FG, MESH_BG))
+       (CONFIG_LEVEL_MAP, MESH_FG, MESH_BG, LW_NETWORK_ON))
       !=NULL)
     {
       mesher=create_first_mesher (map);
@@ -370,7 +371,8 @@ BITMAP *create_mesh_bitmap (int mode)
 
   result=create_textured_map (CONFIG_LEVEL_MAP,
 			      CONFIG_LEVEL_FG,
-			      CONFIG_LEVEL_BG);
+			      CONFIG_LEVEL_BG,
+			      LW_NETWORK_ON);
   if (result)
     {
       for  (i=0;i<CURRENT_MESH_SIZE;++i)
