@@ -56,6 +56,7 @@
 
 #include "config.h"
 #include "mouse.h"
+#include "disk.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -69,66 +70,102 @@ int MOUSE_CONTROL_DOWN;
 int MOUSE_CONTROL_LEFT;
 
 static int MOUSE_CONTROL_GAP;
+static int MOUSE_ON=1;
 
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-void update_mouse_control (void)
+void lw_mouse_update_control (void)
 {
- if (mouse_y<=MOUSE_CONTROL_REF_Y-MOUSE_CONTROL_GAP)
+  if (mouse_y<=MOUSE_CONTROL_REF_Y-MOUSE_CONTROL_GAP)
     {
-     MOUSE_CONTROL_UP=1;
-     MOUSE_CONTROL_REF_Y=mouse_y+MOUSE_CONTROL_GAP;
+      MOUSE_CONTROL_UP=1;
+      MOUSE_CONTROL_REF_Y=mouse_y+MOUSE_CONTROL_GAP;
     }
- else
-     MOUSE_CONTROL_UP=0;
+  else
+    MOUSE_CONTROL_UP=0;
 
- if (mouse_x>=MOUSE_CONTROL_REF_X+MOUSE_CONTROL_GAP)
+  if (mouse_x>=MOUSE_CONTROL_REF_X+MOUSE_CONTROL_GAP)
     {
-     MOUSE_CONTROL_RIGHT=1;
-     MOUSE_CONTROL_REF_X=mouse_x-MOUSE_CONTROL_GAP;
+      MOUSE_CONTROL_RIGHT=1;
+      MOUSE_CONTROL_REF_X=mouse_x-MOUSE_CONTROL_GAP;
     }
- else
-     MOUSE_CONTROL_RIGHT=0;
+  else
+    MOUSE_CONTROL_RIGHT=0;
 
- if (mouse_y>=MOUSE_CONTROL_REF_Y+MOUSE_CONTROL_GAP)
+  if (mouse_y>=MOUSE_CONTROL_REF_Y+MOUSE_CONTROL_GAP)
     {
-     MOUSE_CONTROL_DOWN=1;
-     MOUSE_CONTROL_REF_Y=mouse_y-MOUSE_CONTROL_GAP;
+      MOUSE_CONTROL_DOWN=1;
+      MOUSE_CONTROL_REF_Y=mouse_y-MOUSE_CONTROL_GAP;
     }
- else
-     MOUSE_CONTROL_DOWN=0;
+  else
+    MOUSE_CONTROL_DOWN=0;
 
- if (mouse_x<=MOUSE_CONTROL_REF_X-MOUSE_CONTROL_GAP)
+  if (mouse_x<=MOUSE_CONTROL_REF_X-MOUSE_CONTROL_GAP)
     {
-     MOUSE_CONTROL_LEFT=1;
-     MOUSE_CONTROL_REF_X=mouse_x+MOUSE_CONTROL_GAP;
+      MOUSE_CONTROL_LEFT=1;
+      MOUSE_CONTROL_REF_X=mouse_x+MOUSE_CONTROL_GAP;
     }
- else
-     MOUSE_CONTROL_LEFT=0;
+  else
+    MOUSE_CONTROL_LEFT=0;
 }
 
 /*------------------------------------------------------------------*/
-void reset_mouse_control (void)
+void lw_mouse_reset_control (void)
 {
- MOUSE_CONTROL_REF_X=mouse_x;
- MOUSE_CONTROL_REF_Y=mouse_y;
- MOUSE_CONTROL_GAP= 2+ (8-CONFIG_MOUSE_GAP)
-                       *(8-CONFIG_MOUSE_GAP);
+  MOUSE_CONTROL_REF_X=mouse_x;
+  MOUSE_CONTROL_REF_Y=mouse_y;
+  MOUSE_CONTROL_GAP= 2+ (8-CONFIG_MOUSE_GAP)
+    *(8-CONFIG_MOUSE_GAP);
 
- if (MOUSE_CONTROL_REF_X<MOUSE_CONTROL_GAP)
+  if (MOUSE_CONTROL_REF_X<MOUSE_CONTROL_GAP)
     MOUSE_CONTROL_REF_X=MOUSE_CONTROL_GAP;
- if (MOUSE_CONTROL_REF_Y<MOUSE_CONTROL_GAP)
+  if (MOUSE_CONTROL_REF_Y<MOUSE_CONTROL_GAP)
     MOUSE_CONTROL_REF_Y=MOUSE_CONTROL_GAP;
- if (MOUSE_CONTROL_REF_X>SCREEN_W-MOUSE_CONTROL_GAP-1)
+  if (MOUSE_CONTROL_REF_X>SCREEN_W-MOUSE_CONTROL_GAP-1)
     MOUSE_CONTROL_REF_X=SCREEN_W-MOUSE_CONTROL_GAP-1;
- if (MOUSE_CONTROL_REF_Y>SCREEN_H-MOUSE_CONTROL_GAP-1)
+  if (MOUSE_CONTROL_REF_Y>SCREEN_H-MOUSE_CONTROL_GAP-1)
     MOUSE_CONTROL_REF_Y=SCREEN_H-MOUSE_CONTROL_GAP-1;
 
- position_mouse (MOUSE_CONTROL_REF_X,MOUSE_CONTROL_REF_Y);
- update_mouse_control ();
+  position_mouse (MOUSE_CONTROL_REF_X,MOUSE_CONTROL_REF_Y);
+  lw_mouse_update_control ();
+}
+
+/*------------------------------------------------------------------*/
+void lw_mouse_update_show_hide(void)
+{
+  if (MOUSE_ON)
+    {
+      if (font==BIG_FONT)
+	{
+	  set_mouse_sprite (BIG_MOUSE_CURSOR);
+	}
+      if (font==SMALL_FONT)
+	{
+	  set_mouse_sprite (SMALL_MOUSE_CURSOR);
+	}
+      show_mouse(screen);
+    }
+  else
+    {
+      set_mouse_sprite (INVISIBLE_MOUSE_CURSOR);
+    }
+}
+
+/*------------------------------------------------------------------*/
+void lw_mouse_show (void)
+{
+  MOUSE_ON=1;
+  lw_mouse_update_show_hide();
+}
+
+/*------------------------------------------------------------------*/
+void lw_mouse_hide (void)
+{
+  MOUSE_ON=0;
+  lw_mouse_update_show_hide();
 }
 
 
