@@ -75,7 +75,10 @@ extern int MOUSE_CONTROL_LEFT;
 /* fonctions globales                                               */
 /*==================================================================*/
 
-void update_mouse_control (void);
-void reset_mouse_control (void);
+void lw_mouse_update_control (void);
+void lw_mouse_reset_control (void);
+void lw_mouse_update_show_hide(void);
+void lw_mouse_show (void);
+void lw_mouse_hide (void);
 
 #endif
