@@ -408,7 +408,7 @@ void move_all_cursors (void)
   /*
    * polls the module which wraps mouse moves to virtual keys
    */
-  update_mouse_control();
+  lw_mouse_update_control();
   /*
    * polls the joystick
    */
@@ -449,7 +449,6 @@ void move_all_cursors (void)
 		}
 	    }
 	}
-
       /*
        * we flush network informations if needed.
        */
