@@ -127,18 +127,46 @@ static int read_separator(char **message)
  */
 static char *read_word(char **message)
 {
-  char *begin;
+  char *begin=NULL;
   char *result=NULL;
   int len;
+  char quote_char;
 
   eat_space(message);
-  begin=*message;
-  while ((!isspace(**message)) && (**message)!=',' && (**message)!='\0')
+
+  quote_char=**message;
+
+  if (quote_char == '\"' || quote_char == '\'') 
+    {      
+      /*
+       * We handle strings quoted with ' or ".
+       * No escape character is handled yet...
+       */ 
+      ++(*message);      
+
+      begin=*message;
+
+      while ((**message)!=quote_char && (**message)!='\0')
+	{
+	  ++(*message);
+	}
+
+      len=(*message)-begin;
+
+      ++(*message);      
+    }
+  else
     {
-      ++(*message);
+      begin=*message;
+
+      while ((!isspace(**message)) && (**message)!=',' && (**message)!='\0')
+	{
+	  ++(*message);
+	}
+
+      len=(*message)-begin;
     }
 
-  len=(*message)-begin;
   if (len>=0)
     {
       result=(char *) malloc(len+1);
@@ -193,10 +221,6 @@ static int get_code(char **message)
 	    {
 	      result=LW_NETMESS_CODE_VERSION;
 	    }
-	  else if (strcasecmp(command,LW_NETMESS_TEXT_NICKNAME)==0)
-	    {
-	      result=LW_NETMESS_CODE_NICKNAME;
-	    }
 	  else if (strcasecmp(command,LW_NETMESS_TEXT_FREE)==0)
 	    {
 	      result=LW_NETMESS_CODE_FREE;
@@ -209,6 +233,22 @@ static int get_code(char **message)
 	    {
 	      result=LW_NETMESS_CODE_READY;
 	    }
+	  else if (strcasecmp(command,LW_NETMESS_TEXT_START)==0)
+	    {
+	      result=LW_NETMESS_CODE_START;
+	    }
+	  else if (strcasecmp(command,LW_NETMESS_TEXT_WAITING)==0)
+	    {
+	      result=LW_NETMESS_CODE_WAITING;
+	    }
+	  else if (strcasecmp(command,LW_NETMESS_TEXT_NEXT)==0)
+	    {
+	      result=LW_NETMESS_CODE_NEXT;
+	    }
+	  else if (strcasecmp(command,LW_NETMESS_TEXT_TEAMSTARTINFO)==0)
+	    {
+	      result=LW_NETMESS_CODE_TEAMSTARTINFO;
+	    }
 	  else if (strcasecmp(command,LW_NETMESS_TEXT_WHO)==0)
 	    {
 	      result=LW_NETMESS_CODE_WHO;
