@@ -74,25 +74,28 @@ typedef struct
 /* constants                                                        */
 /*==================================================================*/
 
-#define LW_NETMESS_CODE_UNKNOWN       0
-#define LW_NETMESS_CODE_OK            1
-#define LW_NETMESS_CODE_ERR           2
-#define LW_NETMESS_CODE_PING          3
-#define LW_NETMESS_CODE_ECHO          4
-#define LW_NETMESS_CODE_PROGRAM       5
-#define LW_NETMESS_CODE_VERSION       6
-#define LW_NETMESS_CODE_NICKNAME      7
-#define LW_NETMESS_CODE_FREE          8
-#define LW_NETMESS_CODE_TEAM          9
-#define LW_NETMESS_CODE_READY        10
-#define LW_NETMESS_CODE_WHO          11
-#define LW_NETMESS_CODE_LOCAL        12
-#define LW_NETMESS_CODE_NETWORK      13
-#define LW_NETMESS_CODE_NOBODY       14
-#define LW_NETMESS_CODE_SENDMAP      16
-#define LW_NETMESS_CODE_RECVMAP      17
-#define LW_NETMESS_CODE_SENDCONFIG   18
-#define LW_NETMESS_CODE_RECVCONFIG   19
+#define LW_NETMESS_CODE_UNKNOWN        0
+#define LW_NETMESS_CODE_OK             1
+#define LW_NETMESS_CODE_ERR            2
+#define LW_NETMESS_CODE_PING           3
+#define LW_NETMESS_CODE_ECHO           4
+#define LW_NETMESS_CODE_PROGRAM        5
+#define LW_NETMESS_CODE_VERSION        6
+#define LW_NETMESS_CODE_FREE           7
+#define LW_NETMESS_CODE_TEAM           8
+#define LW_NETMESS_CODE_READY          9
+#define LW_NETMESS_CODE_START         10
+#define LW_NETMESS_CODE_WAITING       11
+#define LW_NETMESS_CODE_NEXT          12
+#define LW_NETMESS_CODE_TEAMSTARTINFO 13
+#define LW_NETMESS_CODE_WHO           14
+#define LW_NETMESS_CODE_LOCAL         15
+#define LW_NETMESS_CODE_NETWORK       16
+#define LW_NETMESS_CODE_NOBODY        17
+#define LW_NETMESS_CODE_SENDMAP       18
+#define LW_NETMESS_CODE_RECVMAP       19
+#define LW_NETMESS_CODE_SENDCONFIG    20
+#define LW_NETMESS_CODE_RECVCONFIG    21
 
 #define LW_NETMESS_TEXT_OK            "OK"
 #define LW_NETMESS_TEXT_ERR           "ERR"
@@ -100,10 +103,13 @@ typedef struct
 #define LW_NETMESS_TEXT_ECHO          "ECHO"
 #define LW_NETMESS_TEXT_PROGRAM       "PROGRAM"
 #define LW_NETMESS_TEXT_VERSION       "VERSION"
-#define LW_NETMESS_TEXT_NICKNAME      "NICKNAME"
 #define LW_NETMESS_TEXT_FREE          "FREE"
 #define LW_NETMESS_TEXT_TEAM          "TEAM"
 #define LW_NETMESS_TEXT_READY         "READY"
+#define LW_NETMESS_TEXT_START         "START"
+#define LW_NETMESS_TEXT_WAITING       "WAITING"
+#define LW_NETMESS_TEXT_NEXT          "NEXT"
+#define LW_NETMESS_TEXT_TEAMSTARTINFO "TEAMSTARTINFO"
 #define LW_NETMESS_TEXT_WHO           "WHO"
 #define LW_NETMESS_TEXT_LOCAL         "LOCAL"
 #define LW_NETMESS_TEXT_NETWORK       "NETWORK"
