@@ -108,23 +108,13 @@ static int recv_ok(int sock)
 int lw_protocol_do_ping (int sock)
 {
   int result=0;
-  char message[LW_SOCK_MESSAGE_SIZE];
-  int ret;
 
   if (lw_sock_send_str(sock,LW_NETMESS_TEXT_PING))
     {
-      /*
-       * On this very message we don't do a loop before geting
-       * the answer. In fact, if "OK" is not answered fast enough
-       * we simply give up. Or the server is busy or the network
-       * is too slow. In any case, we can't play yet.
-       */
-      ret=lw_sock_recv_str(sock,message);
-    
-      if (ret>0)
+      if (recv_ok(sock))
 	{
 	  result=1;
-	}    
+	}
     }
 
   return result;
@@ -174,27 +164,6 @@ int lw_protocol_tell_version (int sock, char *version)
   return result;
 }
 
-/*------------------------------------------------------------------*/
-/*
- * Sends the client's nickname to the server.
- */
-int lw_protocol_tell_nickname (int sock, char *nickname)
-{
-  int result=0;
-  char message[LW_SOCK_MESSAGE_SIZE];
-
-  sprintf(message,"%s %s",LW_NETMESS_TEXT_NICKNAME,nickname);
-  if (lw_sock_send_str(sock,message))
-    {
-      if (recv_ok(sock))
-	{
-	  result=1;
-	}
-    }
-
-  return result;
-}
-
 /*------------------------------------------------------------------*/
 /*
  * Asks the server how many players can connect to it.
@@ -230,14 +199,14 @@ int lw_protocol_ask_free_teams (int sock,int *nb)
 
 /*------------------------------------------------------------------*/
 /*
- * Inform the player that this player will be playing.
+ * Inform the server that this player will be playing.
  */
-int lw_protocol_reserve_team (int sock, int num)
+int lw_protocol_reserve_team (int sock, int num, char *name)
 {
   int result=0;
   char message[LW_SOCK_MESSAGE_SIZE];
 
-  sprintf(message,"%s %d",LW_NETMESS_TEXT_TEAM,num);
+  sprintf(message,"%s %d,'%s'",LW_NETMESS_TEXT_TEAM,num,name);
   if (lw_sock_send_str(sock,message))
     {
       if (recv_ok(sock))
@@ -265,7 +234,7 @@ int lw_protocol_ask_who (int sock,
   who->active=0;
   who->network=0;
   who->server_id=-1;
-  who->nickname[0]='\0';
+  who->name[0]='\0';
 
   sprintf(message,"%s %d",LW_NETMESS_TEXT_WHO,num);
   if (lw_sock_send_str(sock,message))
@@ -287,34 +256,20 @@ int lw_protocol_ask_who (int sock,
 		      result=1;
 		    }
 		  break;
-		case LW_NETMESS_CODE_LOCAL:
-		  if (netmess->argc>=1 && netmess->argc<=2)
-		    {
-		      who->active=1;
-		      who->server_id=atoi(netmess->argv[0]);
-		      if (netmess->argc>=2)
-			{
-			  strncpy(who->nickname,
-				  netmess->argv[1],
-				  NICKNAME_SIZE);
-			  who->nickname[NICKNAME_SIZE]='\0';
-			}
-		      result=1;
-		    }
-		  break;
 		case LW_NETMESS_CODE_NETWORK:
-		  if (netmess->argc>=1 && netmess->argc<=2)
+		  who->network=1;
+		  /*
+		   * no "break" here since the only difference between
+		   * the LOCAL and NETWORK messages is that the network
+		   * flag is set to 1 in the "NETWORK" case.
+		   */
+		case LW_NETMESS_CODE_LOCAL:
+		  if (netmess->argc>=1 && netmess->argc==2)
 		    {
 		      who->active=1;
 		      who->server_id=atoi(netmess->argv[0]);
-		      if (netmess->argc>=2)
-			{
-			  strncpy(who->nickname,
-				  netmess->argv[1],
-				  NICKNAME_SIZE);
-			  who->nickname[NICKNAME_SIZE]='\0';
-			}
-		      who->network=1;
+		      strncpy(who->name,netmess->argv[1],NAME_SIZE);
+		      who->name[NAME_SIZE]='\0';
 		      result=1;
 		    }
 		  break;
@@ -454,6 +409,122 @@ int lw_protocol_i_am_ready (int sock)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Tells the server one is waiting for the game to start
+ */
+int lw_protocol_waiting (int sock, int *waited_teams)
+{
+  int result=0;
+  char message[LW_SOCK_MESSAGE_SIZE];
+  int ret;
+  LW_NETMESS *netmess;
+
+  (*waited_teams)=0;
+
+  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_WAITING))
+    {
+      while ((ret=lw_sock_recv_str(sock,message))==0);
+      if (ret>0)
+	{
+	  netmess=lw_netmess_read(message);
+	  if (netmess!=NULL)
+	    {
+	      if (netmess->code==LW_NETMESS_CODE_OK && netmess->argc==1)
+		{
+		  *waited_teams=atoi(netmess->argv[0]);
+		  result=1;
+		}
+	      lw_netmess_free(netmess);
+	    }
+	}
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Forces the server to start the game
+ */
+int lw_protocol_force_start (int sock)
+{
+  int result=0;
+
+  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_START))
+    {
+      if (recv_ok(sock))
+	{
+	  result=1;
+	}
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Sends a "NEXT" message
+ */
+int lw_protocol_next (int sock)
+{
+  int result=0;
+
+  if (lw_sock_send_str(sock,LW_NETMESS_TEXT_NEXT))
+    {
+      if (recv_ok(sock))
+	{
+	  result=1;
+	}
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Sends a "TEAMSTARTINFO" message
+ */
+int lw_protocol_ask_teamstartinfo (int sock, int team,
+				   LW_TEAMSTARTINFO *team_start_info)
+{
+  int result=0;
+  char message[LW_SOCK_MESSAGE_SIZE];
+  int ret;
+  LW_NETMESS *netmess;
+
+  lw_teamstartinfo_reset(team_start_info);
+
+  sprintf(message,"%s %d",LW_NETMESS_TEXT_TEAMSTARTINFO,team);
+  if (lw_sock_send_str(sock,message))
+    {
+      while ((ret=lw_sock_recv_str(sock,message))==0);
+      if (ret>0)
+	{
+	  netmess=lw_netmess_read(message);
+	  if (netmess!=NULL)
+	    {
+	      switch (netmess->code)
+		{
+		case LW_NETMESS_CODE_OK:
+		  if (netmess->argc==3)
+		    {
+		      team_start_info->active=atoi(netmess->argv[0]);
+		      team_start_info->start=atoi(netmess->argv[1]);
+		      strncpy(team_start_info->name,netmess->argv[2],NAME_SIZE);
+		      team_start_info->name[NAME_SIZE]='\0';
+
+		      result=1;
+		    }
+		  break;
+		}
+	      lw_netmess_free(netmess);
+	    }
+	}
+    }
+
+  return result;
+}
 
 
 
