@@ -68,7 +68,7 @@
 /*==================================================================*/
 
 #define LW_SOCK_NB_BACKLOG               10
-#define LW_SOCK_ACCEPT_SEC               60
+#define LW_SOCK_ACCEPT_SEC                1
 #define LW_SOCK_ACCEPT_USEC               0
 
 #define LW_DESIRED_WINSOCK_VERSION 0x0101 
@@ -172,7 +172,8 @@ int lw_sock_listen(int *sock,int port)
  * Accepts an incoming connexion from a program which has issued a
  * connect. Usefull on the server.
  */
-int lw_sock_accept(int *new_sock,char *ip,int *port,int listening_sock)
+int lw_sock_accept(int *new_sock,char *ip,int *port,
+		   int listening_sock, int wait)
 {
   int result=0;
   struct sockaddr_in name;
@@ -184,32 +185,47 @@ int lw_sock_accept(int *new_sock,char *ip,int *port,int listening_sock)
   int disable=0;
   struct linger li;
 
-  FD_ZERO(&read);
-  FD_SET(listening_sock,&read);
-  tv.tv_sec=LW_SOCK_ACCEPT_SEC;
-  tv.tv_usec=LW_SOCK_ACCEPT_USEC;
-  res=select(listening_sock+1,&read,NULL,NULL,&tv);
-  if (res>=1)
+  *new_sock=-1;
+  ip[0]='\0';
+  *port=0;
+
+  if (listening_sock>=0)
     {
-      (*new_sock)=accept(listening_sock,(struct sockaddr *) &name,&namelen);
-      if ((*new_sock)>=0)
+      FD_ZERO(&read);
+      FD_SET(listening_sock,&read);
+      if (wait)
 	{
-	  li.l_onoff=0;
-	  li.l_linger=0;
-	  setsockopt(*new_sock,SOL_SOCKET,SO_KEEPALIVE,
-		     (char *) &enable,sizeof(int));
-	  setsockopt(*new_sock,SOL_SOCKET,SO_OOBINLINE,
-		     (char *) &disable,sizeof(int));
-	  setsockopt(*new_sock,SOL_SOCKET,SO_LINGER,
-		     (char *) &li,sizeof(struct linger));
+	  tv.tv_sec=LW_SOCK_ACCEPT_SEC;
+	  tv.tv_usec=LW_SOCK_ACCEPT_USEC;
+	}
+      else
+	{
+	  tv.tv_sec=0;
+	  tv.tv_usec=0;
+	}
+      res=select(listening_sock+1,&read,NULL,NULL,&tv);
+      if (res>=1)
+	{
+	  (*new_sock)=accept(listening_sock,(struct sockaddr *) &name,&namelen);
+	  if ((*new_sock)>=0)
+	    {
+	      li.l_onoff=0;
+	      li.l_linger=0;
+	      setsockopt(*new_sock,SOL_SOCKET,SO_KEEPALIVE,
+			 (char *) &enable,sizeof(int));
+	      setsockopt(*new_sock,SOL_SOCKET,SO_OOBINLINE,
+			 (char *) &disable,sizeof(int));
+	      setsockopt(*new_sock,SOL_SOCKET,SO_LINGER,
+			 (char *) &li,sizeof(struct linger));
 
-	  ioctlsocket(*new_sock,FIONBIO,&disable);
+	      ioctlsocket(*new_sock,FIONBIO,&disable);
 
-	  strncpy(ip,inet_ntoa(name.sin_addr),LW_SOCK_IP_SIZE-1);
-	  ip[LW_SOCK_IP_SIZE-1]=0;
-	  (*port)=(int) ntohs(name.sin_port);
+	      strncpy(ip,inet_ntoa(name.sin_addr),LW_SOCK_IP_SIZE-1);
+	      ip[LW_SOCK_IP_SIZE-1]=0;
+	      (*port)=(int) ntohs(name.sin_port);
 
-	  result=1;
+	      result=1;
+	    }
 	}
     }
 
@@ -270,18 +286,26 @@ int lw_sock_connect(int *sock,char *ip,int port)
 /*
  * Closes a socket for good.
  */
-int lw_sock_close(int sock)
+int lw_sock_close(int *sock)
 {
   int result=0;
+  int sock_to_close;
 
-  if (shutdown(sock,2)!=0)
+  /*
+   * We set *sock to 0 before we close it. This should reduce 
+   * thread problems
+   */
+  sock_to_close=*sock;
+  (*sock)=-1;
+
+  if (shutdown(sock_to_close,2)!=0)
     {
       /*
        * We could print a warning here.
        */
     }
 
-  if (close(sock)!=0)
+  if (close(sock_to_close)!=0)
     {
       /*
        * Strange error, was the socket really opened?
