@@ -68,16 +68,17 @@
 /*==================================================================*/
 
 static void reset(LW_SRVCHAN *chan);
-static int handle_ping(LW_SRVCHAN *chan, LW_NETMESS *mess);
-static int handle_echo(LW_SRVCHAN *chan, LW_NETMESS *mess);
-static int handle_program(LW_SRVCHAN *chan, LW_NETMESS *mess);
-static int handle_version(LW_SRVCHAN *chan, LW_NETMESS *mess);
-static int handle_nickname(LW_SRVCHAN *chan, LW_NETMESS *mess);
-static int handle_free(LW_SRVCHAN *chan, LW_NETMESS *mess,
-		       int free_teams);
 static int handle_team(LW_SRVCHAN *chan, LW_NETMESS *mess,
 		       int *free_teams);
 static int handle_ready(LW_SRVCHAN *chan, LW_NETMESS *mess);
+static int handle_start(LW_SRVCHAN *chan, LW_NETMESS *mess);
+static int handle_waiting(LW_SRVCHAN *chan, 
+			  LW_NETMESS *mess,
+			  int free_teams);
+static int handle_next(LW_SRVCHAN *chan, LW_NETMESS *mess,
+		       int *next);
+static int handle_teamstartinfo(LW_SRVCHAN *chan, LW_NETMESS *mess,
+				LW_TEAMSTARTINFO *team_start_info);
 static int handle_who(LW_SRVCHAN *chan, LW_NETMESS *mess);
 static int handle_sendmap(LW_SRVCHAN *chan, LW_NETMESS *mess, 
 			  void **map);
@@ -87,7 +88,6 @@ static int handle_sendconfig(LW_SRVCHAN *chan, LW_NETMESS *mess,
 			     LW_NETCONF *config);
 static int handle_recvconfig(LW_SRVCHAN *chan, LW_NETMESS *mess, 
 			     LW_NETCONF *config);
-static int handle_unknown(LW_SRVCHAN *chan, LW_NETMESS *mess);
 
 /*------------------------------------------------------------------*/
 /*
@@ -102,9 +102,9 @@ static void reset(LW_SRVCHAN *chan)
   chan->port=0;
   chan->program_ok=1; // set to 1 temporary for testing
   chan->version_ok=1; // set to 1 temporary for testing
-  chan->nickname_ok=0;
   chan->ready_ok=0;
-  chan->nickname[0]='\0';
+  chan->start=0;
+  chan->map=NULL;
   for (i=0;i<NB_TEAMS;++i)
     {
       lw_srvteam_reset(&(chan->team[i]));
@@ -115,14 +115,14 @@ static void reset(LW_SRVCHAN *chan)
 /*
  * handles the "PING" message
  */
-static int handle_ping(LW_SRVCHAN *chan, LW_NETMESS *mess)
+int lw_srvchan_handle_ping(int sock, LW_NETMESS *mess)
 {
   int result=0;
 
   /*
    * It's a ping, we answer OK everytime
    */
-  lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK);
+  lw_sock_send_str(sock,LW_NETMESS_TEXT_OK);
   result=1;
 
   return result;
@@ -132,7 +132,7 @@ static int handle_ping(LW_SRVCHAN *chan, LW_NETMESS *mess)
 /*
  * handles the "ECHO" message
  */
-static int handle_echo(LW_SRVCHAN *chan, LW_NETMESS *mess)
+int lw_srvchan_handle_echo(int sock, LW_NETMESS *mess)
 {
   int result=0;
   char answer[LW_SOCK_MESSAGE_SIZE];
@@ -158,7 +158,7 @@ static int handle_echo(LW_SRVCHAN *chan, LW_NETMESS *mess)
       strcat(answer,mess->argv[i]);
       i++;
     }
-  lw_sock_send_str(chan->sock,answer);
+  lw_sock_send_str(sock,answer);
   result=1;
 
   return result;
@@ -168,7 +168,8 @@ static int handle_echo(LW_SRVCHAN *chan, LW_NETMESS *mess)
 /*
  * handles the "PROGRAM" message
  */
-static int handle_program(LW_SRVCHAN *chan, LW_NETMESS *mess)
+int lw_srvchan_handle_program(int sock, LW_NETMESS *mess,
+			      int *ok)
 {
   int result=0;
 
@@ -181,7 +182,7 @@ static int handle_program(LW_SRVCHAN *chan, LW_NETMESS *mess)
        */
       if (strcmp(mess->argv[0],LW_PROGRAM)==0)
 	{
-	  chan->program_ok=1;
+	  (*ok)=1;
 	  result=1;
 	}
     }
@@ -191,11 +192,11 @@ static int handle_program(LW_SRVCHAN *chan, LW_NETMESS *mess)
    */
   if (result)
     {
-      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK);
+      lw_sock_send_str(sock,LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str(sock,LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -205,7 +206,8 @@ static int handle_program(LW_SRVCHAN *chan, LW_NETMESS *mess)
 /*
  * handles the "VERSION" message
  */
-static int handle_version(LW_SRVCHAN *chan, LW_NETMESS *mess)
+int lw_srvchan_handle_version(int sock, LW_NETMESS *mess,
+			      int *ok)
 {
   int result=0;
 
@@ -219,7 +221,7 @@ static int handle_version(LW_SRVCHAN *chan, LW_NETMESS *mess)
        */
       if (strcmp(mess->argv[0],LW_VERSION)==0)
 	{
-	  chan->version_ok=1;
+	  (*ok)=1;
 	  result=1;
 	}
     }
@@ -229,45 +231,11 @@ static int handle_version(LW_SRVCHAN *chan, LW_NETMESS *mess)
    */
   if (result)
     {
-      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK);
+      lw_sock_send_str(sock,LW_NETMESS_TEXT_OK);
     }
   else
     {
-      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
-    }
-
-  return result;
-}
-
-/*------------------------------------------------------------------*/
-/*
- * handles the "NICKNAME" message
- */
-static int handle_nickname(LW_SRVCHAN *chan, LW_NETMESS *mess)
-{
-  int result=0;
-
-  if (mess->argc==1)
-    {
-      /*
-       * OK, there's an argument, we copy it to the nickname field.
-       */
-      strncpy(chan->nickname,mess->argv[0],sizeof(chan->nickname)-1);
-      chan->nickname[sizeof(chan->nickname)-1]='\0';
-      chan->nickname_ok=1;
-      result=1;
-    }
-
-  /*
-   * Now we send feedback on the network
-   */
-  if (result)
-    {
-      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK);
-    }
-  else
-    {
-      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+      lw_sock_send_str(sock,LW_NETMESS_TEXT_ERR);
     }
 
   return result;
@@ -277,14 +245,17 @@ static int handle_nickname(LW_SRVCHAN *chan, LW_NETMESS *mess)
 /*
  * handles the "FREE" message
  */
-static int handle_free(LW_SRVCHAN *chan, LW_NETMESS *mess,int free_teams)
+int lw_srvchan_handle_free(int sock, LW_NETMESS *mess,
+			   int free_teams, int *ok)
 {
   int result=0;
   char answer[LW_SOCK_MESSAGE_SIZE];
 
   sprintf(answer,"%s %d",LW_NETMESS_TEXT_OK,free_teams);
 
-  lw_sock_send_str(chan->sock,answer);
+  lw_sock_send_str(sock,answer);
+
+  (*ok)=1;
   result=1;
 
   return result;
@@ -300,10 +271,12 @@ static int handle_team(LW_SRVCHAN *chan, LW_NETMESS *mess,
   int result=0;
   int i;
 
-  if (mess->argc==1)
+  if (mess->argc==2)
     {
       /*
-       * OK, there's an argument, we interpret it as a number
+       * OK, there are 2 arguments
+       * - arg 1 is the team inde
+       * - arg 2 is the team name
        */
       i=atoi(mess->argv[0]);
       if (i>=0 && i<NB_TEAMS)
@@ -326,6 +299,27 @@ static int handle_team(LW_SRVCHAN *chan, LW_NETMESS *mess,
 		{
 		  (*free_teams)--;
 		  chan->team[i].active=1;
+
+		  strncpy(chan->team[i].name,mess->argv[1],NAME_SIZE);
+		  chan->team[i].name[NAME_SIZE]='\0';
+
+		  log_print_str("Team \"");
+		  log_print_str(mess->argv[1]);
+		  log_print_str("\" on client \"");
+		  log_print_str(chan->ip);
+		  log_print_str(":");
+		  log_print_int(chan->port);
+		  log_println_str("\" accepted");
+		}
+	      else
+		{
+		  log_print_str("Team \"");
+		  log_print_str(mess->argv[1]);
+		  log_print_str("\" on client \"");
+		  log_print_str(chan->ip);
+		  log_print_str(":");
+		  log_print_int(chan->port);
+		  log_println_str("\" refused!");
 		}
 	    }
 	}
@@ -370,17 +364,17 @@ static int handle_who(LW_SRVCHAN *chan, LW_NETMESS *mess)
 	    {
 	      if (chan->team[i].network)
 		{
-		  sprintf(answer,"%s %d,%s",
+		  sprintf(answer,"%s %d,'%s'",
 			  LW_NETMESS_TEXT_NETWORK,
 			  chan->team[i].server_id,
-			  chan->team[i].nickname);
+			  chan->team[i].name);
 		}
 	      else
 		{
-		  sprintf(answer,"%s %d,%s",
+		  sprintf(answer,"%s %d,'%s'",
 			  LW_NETMESS_TEXT_LOCAL,
 			  chan->team[i].server_id,
-			  chan->team[i].nickname);
+			  chan->team[i].name);
 		}
 	    }
 	  else
@@ -424,6 +418,136 @@ static int handle_ready(LW_SRVCHAN *chan, LW_NETMESS *mess)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * handles the "START" message
+ */
+static int handle_start(LW_SRVCHAN *chan, 
+			LW_NETMESS *mess)
+{
+  int result=0;
+
+  /*
+   * Here we just acknowledge the fact that the client required
+   * the game to start right away
+   */
+  chan->start=1;
+  result=1;
+
+  /*
+   * Now we send feedback on the network
+   */
+  if (result)
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK);
+    }
+  else
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * handles the "WAITING" message
+ */
+static int handle_waiting(LW_SRVCHAN *chan, 
+			  LW_NETMESS *mess,
+			  int free_teams)
+{
+  int result=0;
+  char answer[LW_SOCK_MESSAGE_SIZE];
+
+  /*
+   * Here we answer the client the number of free teams
+   */
+  result=1;
+
+  sprintf(answer,"%s %d",
+	  LW_NETMESS_TEXT_OK,
+	  free_teams);
+
+  /*
+   * Now we send feedback on the network
+   */
+  if (result)
+    {
+      lw_sock_send_str(chan->sock,answer);
+    }
+  else
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * handles the "NEXT" message
+ */
+static int handle_next(LW_SRVCHAN *chan, 
+		       LW_NETMESS *mess,
+		       int *next)
+{
+  int result=0;
+
+  /*
+   * Here we do not return "OK" yet.
+   * The point is that the "NEXT" message is like the "READY"
+   * message, it gets an answer when the server decides to
+   * talk to the client again.
+   */
+  (*next)=1;
+  result=1;
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * handles the "TEAMSTARTINFO" message
+ */
+static int handle_teamstartinfo(LW_SRVCHAN *chan, LW_NETMESS *mess,
+				LW_TEAMSTARTINFO *team_start_info)
+{
+  int result=0;
+  int i;
+  char answer[LW_SOCK_MESSAGE_SIZE];
+
+  if (mess->argc==1)
+    {
+      /*
+       * OK, there's an argument, we interpret it as a number
+       */
+      i=atoi(mess->argv[0]);
+      if (i>=0 && i<NB_TEAMS)
+	{
+	  sprintf(answer,"%s %d,%d,'%s'",
+		  LW_NETMESS_TEXT_OK,			  
+		  team_start_info[i].active,
+		  team_start_info[i].start,
+		  team_start_info[i].name);
+
+	  lw_sock_send_str(chan->sock,answer);
+
+	  result=1;
+	}
+    }
+
+  /*
+   * Now we send feedback on the network
+   */
+  if (!result)
+    {
+      lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+    }
+
+  return result;
+}
+
 /*------------------------------------------------------------------*/
 /*
  * handles the "SENDMAP" message
@@ -538,14 +662,14 @@ static int handle_recvconfig(LW_SRVCHAN *chan,
 /*
  * handles an unknown message
  */
-static int handle_unknown(LW_SRVCHAN *chan, LW_NETMESS *mess)
+int lw_srvchan_handle_unknown(int sock, LW_NETMESS *mess)
 {
   int result=0;
 
   /*
    * We answer ERR all the time
    */
-  lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_ERR);
+  lw_sock_send_str(sock,LW_NETMESS_TEXT_ERR);
 
   /*
    * Since we return 0, the connection will be closed...
@@ -569,26 +693,17 @@ int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
   int ret_mess=1;
   char message[LW_SOCK_MESSAGE_SIZE];
   LW_NETMESS *mess;
+  int free_received=0;
 
   reset(chan);
 
-  log_print_str("Waiting for ");
-  log_print_int(*free_teams);
-  if ((*free_teams)>1)
+  if (lw_sock_accept(&(chan->sock),chan->ip,&(chan->port),sock,1))
     {
-      log_print_str(" teams...");
-    }
-  else
-    {
-      log_print_str(" team...");
-    }
-  log_println();
-  if (lw_sock_accept(&(chan->sock),chan->ip,&(chan->port),sock))
-    {
-      log_print_str("Connection from ");
+      log_print_str("Connection from \"");
       log_print_str(chan->ip);
       log_print_str(":");
       log_print_int(chan->port);
+      log_print_str("\"");
       log_println();
       log_flush();
 
@@ -606,22 +721,19 @@ int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
 		  switch (mess->code)
 		    {
 		    case LW_NETMESS_CODE_PING:
-		      ret_mess=handle_ping(chan,mess);
+		      ret_mess=lw_srvchan_handle_ping(chan->sock,mess);
 		      break;
 		    case LW_NETMESS_CODE_ECHO:
-		      ret_mess=handle_echo(chan,mess);
+		      ret_mess=lw_srvchan_handle_echo(chan->sock,mess);
 		      break;
 		    case LW_NETMESS_CODE_PROGRAM:
-		      ret_mess=handle_program(chan,mess);
+		      ret_mess=lw_srvchan_handle_program(chan->sock,mess,&(chan->program_ok));
 		      break;
 		    case LW_NETMESS_CODE_VERSION:
-		      ret_mess=handle_version(chan,mess);
-		      break;
-		    case LW_NETMESS_CODE_NICKNAME:
-		      ret_mess=handle_nickname(chan,mess);
+		      ret_mess=lw_srvchan_handle_version(chan->sock,mess,&(chan->version_ok));
 		      break;
 		    case LW_NETMESS_CODE_FREE:
-		      ret_mess=handle_free(chan,mess,*free_teams);
+		      ret_mess=lw_srvchan_handle_free(chan->sock,mess,*free_teams,&free_received);
 		      break;
 		    case LW_NETMESS_CODE_TEAM:
 		      ret_mess=handle_team(chan,mess,free_teams);
@@ -636,7 +748,7 @@ int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
 		      ret_mess=handle_sendconfig(chan,mess,config);
 		      break;
 		    default:
-		      ret_mess=handle_unknown(chan,mess);
+		      ret_mess=lw_srvchan_handle_unknown(sock,mess);
 		      break;
 		    }
 
@@ -663,15 +775,16 @@ int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
 
       if (chan->program_ok && 
 	  chan->version_ok && 
-	  chan->nickname_ok &&
 	  chan->ready_ok &&
 	  ret_mess)
 	{
 	  result=1;
-	  log_print_str("Accepted \"");
-	  log_print_str(chan->nickname);
-	  log_print_str("\"");
-	  log_println();
+
+	  log_print_str("Client \"");
+	  log_print_str(chan->ip);
+	  log_print_str(":");
+	  log_print_int(chan->port);
+	  log_println_str("\" accepted");
 	}
       else
 	{
@@ -686,9 +799,138 @@ int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
 	       */
 	      lw_sock_send_str(chan->sock, LW_NETMESS_TEXT_ERR);
 	    }
-	  lw_sock_close(chan->sock);
-	  chan->sock=-1;
-	  log_println_str("Rejected!");
+	  lw_sock_close(&(chan->sock));
+
+	  log_print_str("Client \"");
+	  log_print_str(chan->ip);
+	  log_print_str(":");
+	  log_print_int(chan->port);
+	  log_println_str("\" rejected!");
+	}
+    }
+
+  return result;
+} 
+
+/*------------------------------------------------------------------*/
+/*
+ * Sends informations to the client on a regular basis, once it's
+ * connected and waiting for the game to start
+ */
+int lw_srvchan_keepalive(LW_SRVCHAN *chan,
+			 int waited_teams,
+			 LW_TEAMSTARTINFO *team_start_info)
+{
+  int result=0;
+  int ret;
+  int ret_mess=1;
+  char message[LW_SOCK_MESSAGE_SIZE];
+  LW_NETMESS *mess;
+  int next=0;
+
+  /*
+   * we set ready_ok back to false since we will wait for
+   * another ready message
+   */
+  chan->ready_ok=0;
+
+  /*
+   * We first answer the "READY" message which had been sent by the
+   * client a possibly long time ago.
+   */
+  if (lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK))
+    {
+      while ((!chan->ready_ok) && (!next) && ret_mess &&
+	     ((ret=lw_sock_recv_str(chan->sock,message))>=0))
+	{
+	  if (ret>0)
+	    {
+	      mess=lw_netmess_read(message);
+	      if (mess!=NULL)
+		{
+		  /*
+		   * switch to handle the different possible messages
+		   */
+		  switch (mess->code)
+		    {
+		    case LW_NETMESS_CODE_PING:
+		      ret_mess=lw_srvchan_handle_ping(chan->sock,mess);
+		      break;
+		    case LW_NETMESS_CODE_ECHO:
+		      ret_mess=lw_srvchan_handle_echo(chan->sock,mess);
+		      break;
+		    case LW_NETMESS_CODE_START:
+		      ret_mess=handle_start(chan,mess);
+		      break;
+		    case LW_NETMESS_CODE_WAITING:
+		      ret_mess=handle_waiting(chan,mess,
+					      waited_teams);
+		      break;
+		    case LW_NETMESS_CODE_NEXT:
+		      ret_mess=handle_next(chan,mess,&next);
+		      break;
+		    case LW_NETMESS_CODE_TEAMSTARTINFO:
+		      ret_mess=handle_teamstartinfo(chan,mess,
+						    team_start_info);
+		      break;
+		    case LW_NETMESS_CODE_READY:
+		      ret_mess=handle_ready(chan,mess);
+		      break;
+		    default:
+		      ret_mess=lw_srvchan_handle_unknown(chan->sock,mess);
+		      break;
+		    }
+
+		  /*
+		   * lw_netmess_free must *not* be forgetted 
+		   */
+		  lw_netmess_free(mess);
+
+		  if (!ret_mess)
+		    {
+		      log_print_str("Error processing \"");
+		      log_print_str(message);
+		      log_print_str("\"");
+		      log_println();
+		    }
+		}
+	      else
+		{
+		  log_println_str("Serious memory problem 8-(");
+		  ret_mess=0;
+		}
+	    }
+	}
+
+      if ((chan->ready_ok || next) &&
+	  ret_mess)
+	{
+	  result=1;
+	  if (chan->ready_ok)
+	    {
+	      log_print_str("Client \"");
+	      log_print_str(chan->ip);
+	      log_print_str(":");
+	      log_print_int(chan->port);
+	      log_println_str("\" ready");
+	    }
+	}
+      else
+	{
+	  if (chan->ready_ok || next)
+	    {
+	      /*
+	       * Now if we are here it means we have received a "READY"
+	       * message, but still the client did not send the correct
+	       * messages before => we send an "ERR" messageon the
+	       * network for consistency, since the client did not receive
+	       * any message to his "READY" query yet.
+	       */
+	      lw_sock_send_str(chan->sock, LW_NETMESS_TEXT_ERR);
+	    }
+	  lw_sock_close(&(chan->sock));
+
+	  //log_println_str("Player KO");
 	}
     }
 
@@ -707,8 +949,10 @@ int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config)
   char message[LW_SOCK_MESSAGE_SIZE];
   LW_NETMESS *mess;
 
-  log_print_str("Talking to \"");
-  log_print_str(chan->nickname);
+  log_print_str("Sending info to \"");
+  log_print_str(chan->ip);
+  log_print_str(":");
+  log_print_int(chan->port);
   log_print_str("\"");
   log_println();
 
@@ -722,6 +966,7 @@ int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config)
    * We first answer the "READY" message which had been sent by the
    * client a possibly long time ago.
    */
+
   if (lw_sock_send_str(chan->sock,LW_NETMESS_TEXT_OK))
     {
       while ((!chan->ready_ok) && ret_mess &&
@@ -738,10 +983,10 @@ int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config)
 		  switch (mess->code)
 		    {
 		    case LW_NETMESS_CODE_PING:
-		      ret_mess=handle_ping(chan,mess);
+		      ret_mess=lw_srvchan_handle_ping(chan->sock,mess);
 		      break;
 		    case LW_NETMESS_CODE_ECHO:
-		      ret_mess=handle_echo(chan,mess);
+		      ret_mess=lw_srvchan_handle_echo(chan->sock,mess);
 		      break;
 		    case LW_NETMESS_CODE_WHO:
 		      ret_mess=handle_who(chan,mess);
@@ -756,7 +1001,7 @@ int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config)
 		      ret_mess=handle_recvconfig(chan,mess,config);
 		      break;
 		    default:
-		      ret_mess=handle_unknown(chan,mess);
+		      ret_mess=lw_srvchan_handle_unknown(chan->sock,mess);
 		      break;
 		    }
 
@@ -800,8 +1045,8 @@ int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config)
 	       */
 	      lw_sock_send_str(chan->sock, LW_NETMESS_TEXT_ERR);
 	    }
-	  lw_sock_close(chan->sock);
-	  chan->sock=-1;
+	  lw_sock_close(&(chan->sock));
+
 	  //log_println_str("Player KO");
 	}
     }
@@ -823,8 +1068,7 @@ int lw_srvchan_final_ok(LW_SRVCHAN *chan)
     }
   else
     {
-      lw_sock_close(chan->sock);
-      chan->sock=-1;
+      lw_sock_close(&(chan->sock));
     }
 
   return result;
@@ -876,12 +1120,17 @@ int lw_srvchan_find_first_free_team(LW_SRVCHAN *chan)
  */
 void lw_srvchan_close(LW_SRVCHAN *chan)
 {
-  lw_sock_close(chan->sock);
+  lw_sock_close(&(chan->sock));
+
+  if (chan->map!=NULL)
+    {
+      free (chan->map);
+      chan->map=NULL;
+    }
 
   reset(chan);
 }
 
-
 /*------------------------------------------------------------------*/
 /*
  * Receives key presses from a computer.
