@@ -58,10 +58,24 @@
 #include "srvcont.h"
 #include "srvchan.h"
 #include "sockgen.h"
+#include "sock2gen.h"
 #include "log.h"
 #include "server.h"
 #include "netkey.h"
 #include "srvtime.h"
+#include "startinf.h"
+#include "thrdgen.h"
+
+/*==================================================================*/
+/* structs                                                          */
+/*==================================================================*/
+typedef struct
+{
+  int sock;
+  char ip[LW_SOCK_IP_SIZE];
+  int port;
+  int *thread_running;
+} LW_SRVCONT_REJECT_DATA;
 
 /*==================================================================*/
 /* constants                                                        */
@@ -71,6 +85,7 @@
 #define LW_SRVCONT_DECREASE_LAG_LIMIT 20
 
 #define LW_SRVCONT_DISPLAY_STATE_DELAY 60
+#define LW_SRVCONT_REGISTER_DELAY      90
 
 /*==================================================================*/
 /* static functions                                                 */
@@ -78,11 +93,14 @@
 
 static void reset(LW_SRVCONT *cont);
 static int distribute_teams(LW_SRVCONT *cont);
+static void recalc_nb_teams(LW_SRVCONT *cont);
 static void find_chan_and_team_by_server_id(LW_SRVCONT *cont,
 					    int server_id,
 					    int *chan,
 					    int *team);
 static int send_lag_key_presses(LW_SRVCONT *cont,int lag);
+static int reject_new_clients(LW_SRVCONT *cont);
+static void reject_new_clients_callback(void *args);
 
 /*------------------------------------------------------------------*/
 /*
@@ -93,7 +111,6 @@ static void reset(LW_SRVCONT *cont)
   cont->sock=-1;
   cont->nb_teams=0;
   cont->nb_chans=0;
-  cont->map=NULL;
   memset(&(cont->config),0,sizeof(LW_NETCONF));
 }
 
@@ -175,8 +192,8 @@ static int distribute_teams(LW_SRVCONT *cont)
 					      &j_orig);
 	      if (i_orig>=0 && j_orig>=0)
 		{
-		  strcpy(cont->chan[i].team[j].nickname,
-			 cont->chan[i_orig].nickname);
+		  strcpy(cont->chan[i].team[j].name,
+			 cont->chan[i_orig].team[j_orig].name);
 		}
 	      else
 		{
@@ -190,6 +207,27 @@ static int distribute_teams(LW_SRVCONT *cont)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Calculates the cont->nb_teams value
+ */
+static void recalc_nb_teams(LW_SRVCONT *cont)
+{
+  int i,j;
+
+  cont->nb_teams=0;
+  for (i=0;i<cont->nb_chans;++i)
+    {
+      for (j=0;j<NB_TEAMS;++j)
+	{
+	  if (cont->chan[i].team[j].active)
+	    {
+	      cont->nb_teams++;
+	    }
+	}
+    }
+}
+
 /*------------------------------------------------------------------*/
 /*
  * Gets the chan and team index for a given server id
@@ -218,6 +256,36 @@ static void find_chan_and_team_by_server_id(LW_SRVCONT *cont,
     }
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Prepares the LW_TEAMSTARTINFO structures
+ */
+static void prepare_team_start_info(LW_TEAMSTARTINFO *team_start_info,
+				    LW_SRVCONT *cont)
+{
+  int i,j,k;
+
+  for (i=0;i<NB_TEAMS;++i)
+    {
+      lw_teamstartinfo_reset(team_start_info+i);
+    }
+
+  k=0;
+  for (i=0;i<cont->nb_chans;++i)
+    {
+      for (j=0;j<NB_TEAMS;++j)
+	{
+	  if (cont->chan[i].team[j].active && k<NB_TEAMS)
+	    {
+	      team_start_info[k].active=1;
+	      team_start_info[k].start=cont->chan[i].start;
+	      strcpy(team_start_info[k].name,cont->chan[i].team[j].name);  
+	      k++;
+	    }
+	}
+    }  
+}
+
 /*==================================================================*/
 /* global functions                                                 */
 /*==================================================================*/
@@ -226,13 +294,31 @@ static void find_chan_and_team_by_server_id(LW_SRVCONT *cont,
 /* 
  * Waits for a given number of teams to connect
  */
-int lw_srvcont_wait_teams(LW_SRVCONT *cont, int nb_teams, int port)
+int lw_srvcont_wait_teams(LW_SRVCONT *cont, 
+			  LW_WWWSRV_DATA *www_data,
+			  int nb_teams, int port)
 {
-  int free_teams;
+  int free_teams=0;
   int result=0;
+  int i,j;
+  int start;
+  LW_TEAMSTARTINFO team_start_info[NB_TEAMS];
+  int cur_time,last_time;
+  int display_waiting_for=1;
 
   reset(cont);
 
+  cur_time=last_time=lw_srvtime_seconds();
+
+  /*
+   * We register the server on the metaserver for the
+   * first time, with 0 active teams.
+   */
+  www_data->busy_players=cont->nb_teams;
+  www_data->max_players=nb_teams;
+  www_data->log=1;
+  lw_wwwsrv_register(www_data);
+
   if (lw_sock_listen(&(cont->sock),
 		     port))
     {
@@ -244,17 +330,111 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont, int nb_teams, int port)
       /*
        * Now we just wait until there are enough teams connected
        */
-      while (cont->nb_teams<nb_teams && cont->nb_chans<NB_TEAMS)
+      while (cont->nb_teams<nb_teams && 
+	     cont->nb_chans<NB_TEAMS)
 	{
 	  free_teams=nb_teams-cont->nb_teams;
+
+	  if (display_waiting_for)
+	    {
+	      log_print_str("Waiting for ");
+	      log_print_int(free_teams);
+	      if (free_teams>1)
+		{
+		  log_print_str(" teams...");
+		}
+	      else
+		{
+		  log_print_str(" team...");
+		}
+	      log_println();
+
+	      display_waiting_for=0;
+	    }
+
 	  if (lw_srvchan_wait_teams(&(cont->chan[cont->nb_chans]), 
 				    &free_teams,
 				    cont->sock,
-				    &(cont->map),
+				    &(cont->chan[cont->nb_chans].map),
 				    &(cont->config)))
 	    {
 	      cont->nb_teams=nb_teams-free_teams;
 	      ++(cont->nb_chans);
+	      display_waiting_for=1;
+	    }
+
+	  /*
+	   * Now we check if me must force a game start
+	   */
+	  start=1;
+	  for (i=0;i<cont->nb_chans;++i)
+	    {
+	      start=start && cont->chan[i].start;
+	    }
+	  if (start && cont->nb_teams>=2)
+	    {
+	      /*
+	       * OK, all the players have pressed the "start" button and there
+	       * are at least 2 playing teams -> we start the game!
+	       */ 
+	      nb_teams=cont->nb_teams;
+	      free_teams=0;
+	      log_print_str("Starting game with only ");
+	      log_print_int(cont->nb_teams);
+	      log_println_str(" teams");
+	    }
+
+	  /*
+	   * now we send feedback to all the connected teams
+	   */
+	  prepare_team_start_info(team_start_info,cont);
+	  /*
+	   * loop with a step of -1 to handle correcty the
+	   * possible disconnection of players
+	   */
+	  for (i=cont->nb_chans-1;i>=0;--i)
+	    {
+	      if (!lw_srvchan_keepalive(&(cont->chan[i]),
+					free_teams,
+					team_start_info))
+		{
+		  /*
+		   * There's an error with this client, so 
+		   * we're simply going to disconnect it...
+		   */
+		  log_print_str("Disconnecting \"");
+		  log_print_str(cont->chan[i].ip);
+		  log_print_str(":");
+		  log_print_int(cont->chan[i].port);
+		  log_print_str("\"");
+		  log_println();		  
+
+		  lw_srvchan_close(&(cont->chan[i]));
+		  for (j=i+1;j<cont->nb_chans;++j)
+		    {
+		      cont->chan[j-1]=cont->chan[j];
+		    }
+		  cont->nb_chans--;
+
+		  display_waiting_for=1;
+		}
+	    }
+	  recalc_nb_teams(cont);
+
+	  www_data->busy_players=cont->nb_teams;
+	  www_data->max_players=nb_teams;
+
+	  /*
+	   * We register the server again since the number of 
+	   * connected teams might have changed
+	   */
+	  cur_time=lw_srvtime_seconds();
+	  if (cur_time-last_time>LW_SRVCONT_REGISTER_DELAY
+	      || display_waiting_for)
+	    {
+	      www_data->log=0;      
+	      lw_wwwsrv_register(www_data);
+	      last_time=cur_time;
 	    }
 	}
 
@@ -270,6 +450,12 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont, int nb_teams, int port)
       log_print_str("Unable to bind socket on port ");
       log_print_int(port);
       log_println("!");
+
+      /*
+       * We consider this a fatal error and quit the program
+       * right away.
+       */
+      lw_server_exit(1);
     }
 
   return result;
@@ -284,20 +470,13 @@ int lw_srvcont_tell_who(LW_SRVCONT *cont)
   int i;
   int result=0;
 
-  /*
-   * Now we close the main socket which was accepting new connections.
-   * If we did not do this the server would keep on accepting
-   * connections, which is baaaad.
-   */
-  lw_sock_close(cont->sock);
-
   if (distribute_teams(cont))
     {
       result=1;
       for (i=0;i<cont->nb_chans;++i)
 	{
 	  if (!lw_srvchan_tell_who(&(cont->chan[i]),
-				   cont->map,
+				   cont->chan[0].map,
 				   &(cont->config)))
 	    {
 	      result=0;
@@ -373,7 +552,9 @@ static int send_lag_key_presses(LW_SRVCONT *cont,int lag)
 /* 
  * Sends a final OK message to all the clients
  */
-int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
+int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
+			      LW_WWWSRV_DATA *www_data,
+			      int lag)
 {
   int result=1;
   LW_NETKEY netkey;
@@ -387,9 +568,12 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
   int rounds=0;
   int last_rounds=0;
   int average_lag=0;
-  time_t start,end;
+  time_t start,start2,end;
   double elapsed;
 
+  www_data->log=1;
+  lw_wwwsrv_register(www_data);
+
   result=send_lag_key_presses(cont,lag);
 
   if (!result)
@@ -399,12 +583,18 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
     }
   else
     {
-      start=lw_srvtime_seconds();
+      start2=start=lw_srvtime_seconds();
 
       while (cont->nb_chans>0)
 	{
 	  lw_netkey_reset(&netkey);
 
+	  /*
+	   * We still listen on the listening socket, to reject
+	   * newcomers since the game already started
+	   */
+	  reject_new_clients(cont);
+
 	  all_clients_request_increase_lag=1;
 	  all_clients_request_decrease_lag=1;
 	  a_client_requests_increase_lag=0;
@@ -450,9 +640,13 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
 		   * so we decide to "close" it.
 		   */
 		  log_print_str("Disconnecting \"");
-		  log_print_str(cont->chan[i].nickname);
+		  log_print_str(cont->chan[i].ip);
+		  log_print_str(":");
+		  log_print_int(cont->chan[i].port);
 		  log_print_str("\"");
 		  log_println();
+
+		  lw_srvchan_close(&(cont->chan[i]));
 		  for (j=i+1;j<cont->nb_chans;++j)
 		    {
 		      cont->chan[j-1]=cont->chan[j];
@@ -523,13 +717,18 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
 		{
 		  if (!lw_srvchan_send_keys(&(cont->chan[i]),&netkey))
 		    {
-		      log_print_str("Disconnecting ");
-		      log_print_str(cont->chan[i].nickname);
-		      log_println();
 		      /*
 		       * There's been an error receiving data from this team
 		       * so we decide to "close" it.
 		       */
+		      log_print_str("Disconnecting \"");
+		      log_print_str(cont->chan[i].ip);
+		      log_print_str(":");
+		      log_print_int(cont->chan[i].port);
+		      log_print_str("\"");
+		      log_println();
+
+		      lw_srvchan_close(&(cont->chan[i]));
 		      for (j=i+1;j<cont->nb_chans;++j)
 			{
 			  cont->chan[j-1]=cont->chan[j];
@@ -568,6 +767,14 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag)
 	      last_rounds=0;
 	      average_lag=0;
 	    }
+
+	  if (end-start2>LW_SRVCONT_REGISTER_DELAY)
+	    {
+	      start2+=LW_SRVCONT_REGISTER_DELAY;
+
+	      www_data->log=0;
+	      lw_wwwsrv_register(www_data);
+	    }
 	}
     }
 
@@ -582,7 +789,7 @@ void lw_srvcont_close(LW_SRVCONT *cont)
 {
   int i;
 
-  lw_sock_close(cont->sock);
+  lw_sock_close(&(cont->sock));
 
   log_print_str("Game over");
   log_println();
@@ -592,11 +799,149 @@ void lw_srvcont_close(LW_SRVCONT *cont)
       lw_srvchan_close(&(cont->chan[i]));
     }
 
-  if (cont->map!=NULL)
-    {
-      free (cont->map);
-    }
-
   reset(cont);
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Launches a thread which will handle new connections while
+ * other players are playing.
+ */
+static int reject_new_clients(LW_SRVCONT *cont)
+{
+  int result=0;
+  static LW_SRVCONT_REJECT_DATA data;
+  static int thread_running=0;
+
+  /*
+   * If there's already a thread answering to a client, we do nothing,
+   * for we can answer later, and it makes programming easier and
+   * safer. In any case, the answer we're going to give to the client
+   * is: "there's no room for you guy" so it's not that bad to be
+   * a little late when answering.
+   */
+  if (!thread_running)
+    {
+      data.sock=-1;
+      data.ip[0]='\0';
+      data.port=0;
+      data.thread_running=&thread_running;
+
+      if (lw_sock_accept(&(data.sock),data.ip,&(data.port),cont->sock,0))
+	{
+	  thread_running=1;
+	  result=lw_thread_start(reject_new_clients_callback,(void *) &data);
+	  if (!result)
+	    {
+	      lw_sock_close(&(data.sock));
+	      thread_running=0;
+	    }
+	}
+      else
+	{
+	  /*
+	   * privacy is set to 0, we do not tell anyone about this server
+	   */
+	  result=1;
+	}
+    }
+  else
+    {
+      result=1;
+    }
+
+  return result;
+}
+
+/*------------------------------------------------------------------*/
+/*
+ * Main function of the server thread which tries to connect
+ * on the metaserver
+ */
+static void reject_new_clients_callback(void *args)
+{
+  LW_SRVCONT_REJECT_DATA data;
+  int ret;
+  int ret_mess=1;
+  char message[LW_SOCK_MESSAGE_SIZE];
+  LW_NETMESS *mess;
+  int program=0;
+  int version=0;
+  int free_received=0;
+
+  memcpy(&data, args, sizeof(LW_SRVCONT_REJECT_DATA));
+
+  log_print_str("Connection from \"");
+  log_print_str(data.ip);
+  log_print_str(":");
+  log_print_int(data.port);
+  log_print_str("\"");
+  log_println();
+  log_flush();
+
+  while ((!free_received) && ret_mess &&
+	 ((ret=lw_sock_recv_str(data.sock,message))>=0))
+    {
+      if (ret>0)
+	{
+	  mess=lw_netmess_read(message);
+	  if (mess!=NULL)
+	    {
+	      /*
+	       * switch to handle the different possible messages
+	       */
+	      switch (mess->code)
+		{
+		case LW_NETMESS_CODE_PING:
+		  ret_mess=lw_srvchan_handle_ping(data.sock,mess);
+		  break;
+		case LW_NETMESS_CODE_ECHO:
+		  ret_mess=lw_srvchan_handle_echo(data.sock,mess);
+		  break;
+		case LW_NETMESS_CODE_PROGRAM:
+		  ret_mess=lw_srvchan_handle_program(data.sock,mess,&program);
+		  break;
+		case LW_NETMESS_CODE_VERSION:
+		  ret_mess=lw_srvchan_handle_version(data.sock,mess,&version);
+		  break;
+		case LW_NETMESS_CODE_FREE:
+		  ret_mess=lw_srvchan_handle_free(data.sock,mess,0,&free_received);
+		  break;
+		default:
+		  ret_mess=lw_srvchan_handle_unknown(data.sock,mess);
+		  break;
+		}
+
+	      /*
+	       * lw_netmess_free must *not* be forgetted 
+	       */
+	      lw_netmess_free(mess);
+
+	      if (!ret_mess)
+		{
+		  log_print_str("Error processing \"");
+		  log_print_str(message);
+		  log_print_str("\"");
+		  log_println();
+		}
+	    }
+	  else
+	    {
+	      log_println_str("Serious memory problem 8-(");
+	      ret_mess=0;
+	    }
+	}
+    }
+     
+  log_print_str("Refusing \"");
+  log_print_str(data.ip);
+  log_print_str(":");
+  log_print_int(data.port);
+  log_print_str("\"");
+  log_println();
+ 
+  lw_sock_close(&(data.sock));
+  (*(data.thread_running))=0;
+}
+
+  
