@@ -58,6 +58,7 @@
 #include "base.h"
 #include "srvchan.h"
 #include "netconf.h"
+#include "wwwsrv.h"
 
 /*==================================================================*/
 /* structs                                                          */
@@ -69,7 +70,6 @@ typedef struct
   int nb_teams;
   int nb_chans;
   LW_SRVCHAN chan[NB_TEAMS];
-  void *map;
   LW_NETCONF config;
 } LW_SRVCONT;
 
@@ -77,10 +77,14 @@ typedef struct
 /* fonctions globales                                               */
 /*==================================================================*/
 
-int lw_srvcont_wait_teams(LW_SRVCONT *cont, int nb_teams,int port);
+int lw_srvcont_wait_teams(LW_SRVCONT *cont, 
+			  LW_WWWSRV_DATA *www_data,
+			  int nb_teams,int port);
 int lw_srvcont_tell_who(LW_SRVCONT *cont);
 int lw_srvcont_final_ok(LW_SRVCONT *cont);
-int lw_srvcont_replicate_keys(LW_SRVCONT *cont,int lag);
+int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
+			      LW_WWWSRV_DATA *www_data,
+			      int lag);
 void lw_srvcont_close(LW_SRVCONT *cont);
 
 #endif
