@@ -58,6 +58,7 @@
 
 #include "parser.h"
 #include "startup.h"
+#include "server.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -84,8 +85,10 @@
 #define IDENT_MAP                 "map"
 #define IDENT_TEX                 "tex"
 #define IDENT_MID                 "mid"
+#define IDENT_METASERVER          "metaserver"
 
 #define STARTUP_MAX_PATH_LENGTH           1000
+#define STARTUP_MAX_METASERVER_LENGTH      200
 
 #ifdef ALLEGRO_DOS
 int STARTUP_BIG_DATA=8192;
@@ -108,21 +111,23 @@ int STARTUP_AUTO=0;
 int STARTUP_CHECK=0;
 
 #ifdef ALLEGRO_UNIX
-  static char *DEFAULT_CFG_PATH=CONFIG_UNIX_CFG;
-  static char *DEFAULT_DAT_PATH=CONFIG_UNIX_DAT;
-  static char *DEFAULT_LOG_PATH="";
-  static char *DEFAULT_MAP_PATH=CONFIG_UNIX_MAP;
-  static char *DEFAULT_TEX_PATH=CONFIG_UNIX_TEX;
-  static char *DEFAULT_MID_PATH=CONFIG_UNIX_MID;
+static char *DEFAULT_CFG_PATH=CONFIG_UNIX_CFG;
+static char *DEFAULT_DAT_PATH=CONFIG_UNIX_DAT;
+static char *DEFAULT_LOG_PATH="";
+static char *DEFAULT_MAP_PATH=CONFIG_UNIX_MAP;
+static char *DEFAULT_TEX_PATH=CONFIG_UNIX_TEX;
+static char *DEFAULT_MID_PATH=CONFIG_UNIX_MID;
 #else
-  static char *DEFAULT_CFG_PATH="data/lw.cfg";
-  static char *DEFAULT_DAT_PATH="data/lw.dat";
-  static char *DEFAULT_LOG_PATH="data/lw.log";
-  static char *DEFAULT_MAP_PATH="custom/map/";
-  static char *DEFAULT_TEX_PATH="custom/texture/";
-  static char *DEFAULT_MID_PATH="custom/music/";
+static char *DEFAULT_CFG_PATH="data/lw.cfg";
+static char *DEFAULT_DAT_PATH="data/lw.dat";
+static char *DEFAULT_LOG_PATH="data/lw.log";
+static char *DEFAULT_MAP_PATH="custom/map/";
+static char *DEFAULT_TEX_PATH="custom/texture/";
+static char *DEFAULT_MID_PATH="custom/music/";
 #endif
 
+static char *DEFAULT_METASERVER=LW_SERVER_DEFAULT_METASERVER;
+
 char STARTUP_CFG_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_DAT_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_LOG_PATH[STARTUP_MAX_PATH_LENGTH];
@@ -130,6 +135,8 @@ char STARTUP_MAP_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_TEX_PATH[STARTUP_MAX_PATH_LENGTH];
 char STARTUP_MID_PATH[STARTUP_MAX_PATH_LENGTH];
 
+char STARTUP_METASERVER[STARTUP_MAX_METASERVER_LENGTH];
+
 /*==================================================================*/
 /* fonctions                                                        */
 /*==================================================================*/
@@ -137,206 +144,219 @@ char STARTUP_MID_PATH[STARTUP_MAX_PATH_LENGTH];
 /*------------------------------------------------------------------*/
 static void set_bigdata_size (void)
 {
- int bigd;
+  int bigd;
 
- if (exist_argument_value(IDENT_MEM))
+  if (exist_argument_value(IDENT_MEM))
     {
-     bigd=get_argument_int(IDENT_MEM);
-     if (bigd<1)
+      bigd=get_argument_int(IDENT_MEM);
+      if (bigd<1)
         bigd=1;
-     if (bigd>32)
+      if (bigd>32)
         bigd=32;
-     STARTUP_BIG_DATA=bigd*1024;
+      STARTUP_BIG_DATA=bigd*1024;
     }
 }
 
 /*------------------------------------------------------------------*/
 static void set_joystick (void)
 {
- if (exist_argument (IDENT_NOJOY))
+  if (exist_argument (IDENT_NOJOY))
     STARTUP_JOYSTICK_ON=0;
 }
 
 /*------------------------------------------------------------------*/
 static void set_load_states (void)
 {
- if (exist_argument (IDENT_NOBACK))
+  if (exist_argument (IDENT_NOBACK))
     STARTUP_BACK_STATE=0;
- if (exist_argument (IDENT_NOTEXTURE))
+  if (exist_argument (IDENT_NOTEXTURE))
     STARTUP_TEXTURE_STATE=0;
 
- if (exist_argument (IDENT_NOWATER)
-    || exist_argument (IDENT_NOSOUND))
+  if (exist_argument (IDENT_NOWATER)
+      || exist_argument (IDENT_NOSOUND))
     STARTUP_WATER_STATE=0;
- if (exist_argument (IDENT_NOSFX)
-    || exist_argument (IDENT_NOSOUND))
+  if (exist_argument (IDENT_NOSFX)
+      || exist_argument (IDENT_NOSOUND))
     STARTUP_SFX_STATE=0;
 
- if (exist_argument (IDENT_NOSOUND)
-    || ( exist_argument (IDENT_NOSFX)
-    && exist_argument (IDENT_NOWATER)))
+  if (exist_argument (IDENT_NOSOUND)
+      || ( exist_argument (IDENT_NOSFX)
+	   && exist_argument (IDENT_NOWATER)))
     STARTUP_DIGI_CARD=DIGI_NONE;
 
- if (exist_argument (IDENT_NOMUSIC)
-     || ( exist_argument (IDENT_NOSOUND)))
-   {
-     STARTUP_MUSIC_STATE=0;
-     STARTUP_MIDI_CARD=MIDI_NONE;
-   }
+  if (exist_argument (IDENT_NOMUSIC)
+      || ( exist_argument (IDENT_NOSOUND)))
+    {
+      STARTUP_MUSIC_STATE=0;
+      STARTUP_MIDI_CARD=MIDI_NONE;
+    }
  
- if (exist_argument (IDENT_NOCUSTOM))
+  if (exist_argument (IDENT_NOCUSTOM))
     STARTUP_CUSTOM_STATE=0;
 }
 
 /*------------------------------------------------------------------*/
 static void set_graphic_possibilities (void)
 {
- if (exist_argument (IDENT_NOSVGA))
+  if (exist_argument (IDENT_NOSVGA))
     STARTUP_SVGA=0;
 }
 
 /*------------------------------------------------------------------*/
 static void set_c_or_asm (void)
 {
- if (exist_argument (IDENT_NOASM))
+  if (exist_argument (IDENT_NOASM))
     STARTUP_ASM=0;
 }
 
 /*------------------------------------------------------------------*/
 static void set_stop (void)
 {
- if (exist_argument (IDENT_STOP))
+  if (exist_argument (IDENT_STOP))
     STARTUP_STOP=1;
 }
 
 /*------------------------------------------------------------------*/
 static void set_auto_check (void)
 {
- if (exist_argument (IDENT_AUTO))
+  if (exist_argument (IDENT_AUTO))
     {
-     STARTUP_AUTO=1;
-     STARTUP_CHECK=0;
+      STARTUP_AUTO=1;
+      STARTUP_CHECK=0;
     }
- if (exist_argument (IDENT_CHECK))
+  if (exist_argument (IDENT_CHECK))
     {
-     STARTUP_AUTO=0;
-     STARTUP_CHECK=1;
-     STARTUP_STOP=1;
+      STARTUP_AUTO=0;
+      STARTUP_CHECK=1;
+      STARTUP_STOP=1;
     }
 }
 
 /*------------------------------------------------------------------*/
 static void set_safe (void)
 {
- if (exist_argument (IDENT_NICE))
+  if (exist_argument (IDENT_NICE))
     {
-     STARTUP_BIG_DATA=4096;
-     STARTUP_SVGA=0;
+      STARTUP_BIG_DATA=4096;
+      STARTUP_SVGA=0;
     }
 
- if (exist_argument (IDENT_SAFE))
+  if (exist_argument (IDENT_SAFE))
     {
-     STARTUP_JOYSTICK_ON=0;
-     STARTUP_BIG_DATA=1024;
-     STARTUP_DIGI_CARD=DIGI_NONE;
-     STARTUP_BACK_STATE=0;
-     STARTUP_TEXTURE_STATE=0;
-     STARTUP_WATER_STATE=0;
-     STARTUP_SFX_STATE=0;
-     STARTUP_MUSIC_STATE=0;
-     STARTUP_CUSTOM_STATE=0;
-     STARTUP_SVGA=0;
+      STARTUP_JOYSTICK_ON=0;
+      STARTUP_BIG_DATA=1024;
+      STARTUP_DIGI_CARD=DIGI_NONE;
+      STARTUP_BACK_STATE=0;
+      STARTUP_TEXTURE_STATE=0;
+      STARTUP_WATER_STATE=0;
+      STARTUP_SFX_STATE=0;
+      STARTUP_MUSIC_STATE=0;
+      STARTUP_CUSTOM_STATE=0;
+      STARTUP_SVGA=0;
     }
 }
 
 /*------------------------------------------------------------------*/
 static void correct_path (char *path)
 {
- int l;
- char c;
+  int l;
+  char c;
 
- l=strlen (path);
- if (l>0)
+  l=strlen (path);
+  if (l>0)
     {
-     c=path[l-1];
-     if (c=='/' || c=='\\')
-      {
-        path[--l]=0;
-      }
+      c=path[l-1];
+      if (c=='/' || c=='\\')
+	{
+	  path[--l]=0;
+	}
     }
+
+  fix_filename_case(path);
+  fix_filename_slashes(path);
 }
 
 /*------------------------------------------------------------------*/
 static void set_path (void)
 {
- char home_path[512];
- char *home_env;
+  char home_path[512];
+  char *home_env;
 
- if (exist_argument_value (IDENT_CFG))
-     strcpy(STARTUP_CFG_PATH,get_argument_str (IDENT_CFG));
- else
+  if (exist_argument_value (IDENT_CFG))
+    strcpy(STARTUP_CFG_PATH,get_argument_str (IDENT_CFG));
+  else
     {
-    #ifdef ALLEGRO_UNIX
-         home_env=getenv("HOME"); 
-         strcpy(home_path,home_env);
-         strcat(home_path,"/");
-    #else
-         home_env="";
-         strcpy(home_path,home_env);
-    #endif
-     strcpy(STARTUP_CFG_PATH,home_path);
-     strcat(STARTUP_CFG_PATH,DEFAULT_CFG_PATH);
+#ifdef ALLEGRO_UNIX
+      home_env=getenv("HOME"); 
+      strcpy(home_path,home_env);
+      strcat(home_path,"/");
+#else
+      home_env="";
+      strcpy(home_path,home_env);
+#endif
+      strcpy(STARTUP_CFG_PATH,home_path);
+      strcat(STARTUP_CFG_PATH,DEFAULT_CFG_PATH);
     }
 
- strcpy(STARTUP_LOG_PATH,DEFAULT_LOG_PATH);
+  strcpy(STARTUP_LOG_PATH,DEFAULT_LOG_PATH);
 
- if (exist_argument_value (IDENT_DAT))
-     strcpy(STARTUP_DAT_PATH,get_argument_str (IDENT_DAT));
- else
-     strcpy(STARTUP_DAT_PATH,DEFAULT_DAT_PATH);
+  if (exist_argument_value (IDENT_DAT))
+    strcpy(STARTUP_DAT_PATH,get_argument_str (IDENT_DAT));
+  else
+    strcpy(STARTUP_DAT_PATH,DEFAULT_DAT_PATH);
 
- if (exist_argument_value (IDENT_TEX))
-     strcpy(STARTUP_TEX_PATH,get_argument_str (IDENT_TEX));
- else
-     strcpy(STARTUP_TEX_PATH,DEFAULT_TEX_PATH);
+  if (exist_argument_value (IDENT_TEX))
+    strcpy(STARTUP_TEX_PATH,get_argument_str (IDENT_TEX));
+  else
+    strcpy(STARTUP_TEX_PATH,DEFAULT_TEX_PATH);
 
- if (exist_argument_value (IDENT_MAP))
-     strcpy(STARTUP_MAP_PATH,get_argument_str (IDENT_MAP));
- else
-     strcpy(STARTUP_MAP_PATH,DEFAULT_MAP_PATH);
+  if (exist_argument_value (IDENT_MAP))
+    strcpy(STARTUP_MAP_PATH,get_argument_str (IDENT_MAP));
+  else
+    strcpy(STARTUP_MAP_PATH,DEFAULT_MAP_PATH);
 
- if (exist_argument_value (IDENT_MID))
-     strcpy(STARTUP_MID_PATH,get_argument_str (IDENT_MID));
- else
-     strcpy(STARTUP_MID_PATH,DEFAULT_MID_PATH);
+  if (exist_argument_value (IDENT_MID))
+    strcpy(STARTUP_MID_PATH,get_argument_str (IDENT_MID));
+  else
+    strcpy(STARTUP_MID_PATH,DEFAULT_MID_PATH);
 
 
- correct_path (STARTUP_TEX_PATH);
- correct_path (STARTUP_MAP_PATH);
- correct_path (STARTUP_MID_PATH);
+  correct_path (STARTUP_TEX_PATH);
+  correct_path (STARTUP_MAP_PATH);
+  correct_path (STARTUP_MID_PATH);
 }
 
 /*------------------------------------------------------------------*/
 static void set_platform_specific (void)
 {
-	#ifdef ALLEGRO_WINDOWS
-		STARTUP_ASM=0;	
-	#endif
+#ifdef ALLEGRO_WINDOWS
+  STARTUP_ASM=0;	
+#endif
+}
+
+/*------------------------------------------------------------------*/
+static void set_metaserver (void)
+{
+  if (exist_argument_value (IDENT_METASERVER))
+    strcpy(STARTUP_METASERVER,get_argument_str (IDENT_METASERVER));
+  else
+    strcpy(STARTUP_METASERVER,DEFAULT_METASERVER);   
 }
 
 /*------------------------------------------------------------------*/
 void set_startup (void)
 {
- set_joystick();
- set_load_states();
- set_graphic_possibilities();
- set_c_or_asm();
- set_path();
- set_stop();
- set_safe();
- set_auto_check();
- set_bigdata_size();
- set_platform_specific();
+  set_joystick();
+  set_load_states();
+  set_graphic_possibilities();
+  set_c_or_asm();
+  set_path();
+  set_stop();
+  set_safe();
+  set_auto_check();
+  set_bigdata_size();
+  set_platform_specific();
+  set_metaserver();
 }
 
 
