@@ -54,12 +54,37 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include "base.h"
+
 /*==================================================================*/
 /* structs                                                          */
 /*==================================================================*/
 
+typedef struct
+{
+  int privacy;
+  int log;
+  char metaserver[URL_SIZE+1];
+  int port;
+  int busy_players;
+  int max_players;
+  char password[PASSWORD_SIZE+1];
+  char comment[COMMENT_SIZE+1];
+} LW_WWWSRV_DATA;
+
 /*==================================================================*/
 /* fonctions globales                                               */
 /*==================================================================*/
 
+void lw_wwwsrv_init(LW_WWWSRV_DATA *data, 
+		    int privacy,
+		    int log,
+		    char *metaserver,
+		    int port,
+		    int busy_players,
+		    int max_players,
+		    char *password,
+		    char *comment);
+int lw_wwwsrv_register(LW_WWWSRV_DATA *data);
+
 #endif
